/// \file camara.cpp Camara de juego.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <SDL/SDL.h>
#include <SDL/SDL_image.h>
#include <iostream>
#include "camara.h"

Camara::Camara(int ancho, int alto)
{
	// Establecemos la posición inicial de la cámara.
	camara_.x = 0;
	camara_.y = 0;

	// Establecemos el ancho y el alto de la cámara.
	camara_.w = ancho;
	camara_.h = alto;
}

void Camara::Centrar(const SDL_Rect& objetivo, const SDL_Rect& superficie)
{
	// El objetivo que queremos enfocar está en la mitad derecha
	// de la superficie de enfoque. Obtenemos las cordenadas.
	if(objetivo.x > superficie.w / 2)
	{
		if(superficie.w - objetivo.x < camara_.w / 2)
			camara_.x = objetivo.x - camara_.w + (superficie.w
				- objetivo.x);
		else
			camara_.x = objetivo.x - camara_.w / 2;
	}
	// El objetivo que queremos enfocar está en la mitad izquierda
	// de la superficie de enfoque. Obtenemos las cordenadas.
	else
	{
		if(objetivo.x < camara_.w / 2)
			camara_.x = 0;
		else
			camara_.x = objetivo.x - camara_.w / 2;
	}

	// El objetivo que queremos enfocar está en la mitad inferior
	// de la superficie de enfoque. Obtenemos las cordenadas.
	if(objetivo.y > superficie.h / 2)
	{
		if(superficie.h - objetivo.y < camara_.h / 2)
			camara_.y = objetivo.y - camara_.h + (superficie.h
				- objetivo.y);
		else
			camara_.y = objetivo.y - camara_.h / 2;
	}
	// El objetivo que queremos enfocar está en la mitad superior
	// de la superficie de enfoque. Obtenemos las cordenadas.
	else
	{
		if(objetivo.y < camara_.h / 2)
			camara_.y = 0;
		else
			camara_.y = objetivo.y - camara_.h / 2;
	}
}

const SDL_Rect& Camara::Posicion() const
{
	// Devolvemos la posición de la cámara.
	return camara_;
}

SDL_Rect& Camara::Posicion(const SDL_Rect& posicion)
{
	// Devolvemos la posición relativa a la posición de la cámara.
	posicion_real_.x = posicion.x - camara_.x;
	posicion_real_.y = posicion.y - camara_.y;
	posicion_real_.w = posicion.w;
	posicion_real_.h = posicion.h;
	return posicion_real_;
}
