/// \file camara.h Camara de juego.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _CAMARA_H_
#define _CAMARA_H_

#include <SDL/SDL.h>

/*! \class Camara 
    \brief Cámara de juego.

		La clase cámara se encarga de centrar en la pantalla la posición del campo
		en el que se encuentra la bola de golf.
		
		Cuando la bola de golf se está desplazando, la cámara la acompaña en su
		recorrido, simulando de esta forma la extensión del campo golf.
 */
class Camara
{
	public:
		/*! Constructor de la Camara.\n
				Establece el ancho y alto de la cámara, así como sus coordenadas.
				\brief Constructor.
				\param ancho Ancho de enfoque que tendrá la cámara.
				\param alto Alto de enfoque que tendrá la cámara.
				\see Pantalla::Ancho.
				\see Pantalla::Alto.
		 */
		Camara(int ancho, int alto);

		/*! Centra la Camara en la posición indicada.
				\brief Centra la cámara en un objetivo.
				\param objetivo Posición del objeto que tiene que enfocar la Camara.
				\param superficie Superficie en la que se encuentra el objetivo.
		 */
		void Centrar(const SDL_Rect& objetivo, const SDL_Rect& superficie);

		/*! \brief Posición de la cámara.
				\return Posición en la que se encuentra la Camara.
		 */
		const SDL_Rect& Posicion() const;
		
		/*! Devuelve la posición relativa de un objeto con respecto a la cámara.
				\brief Posición relativa de un objeto.
				\return Posición del objeto con respecto a la cámara.
		 */		
		SDL_Rect& Posicion(const SDL_Rect& posicion);

	private:
		SDL_Rect camara_;	///< Rectángulo de posición de la cámara.
		SDL_Rect posicion_real_;	///< Rectángulo de posición para la posición
															///< real del objeto.
};

#endif
