/// \file datos.h Declaraciones de las clases de datos.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _DATOS_H_
#define _DATOS_H_

#include <SDL/SDL.h>
#include <map>
#include <iostream>

/*!	\namespace Datos.
		\brief Datos de los elementos de la Partida.
 */
namespace Datos
{
/*! \class Bola
    \brief Descripción del desplazamiento de la Bola.

    Datos del desplazamiento de la Bola necesarios para poder restaurar
    la Bola en una posición fuera de colisiones.
 */
	struct Bola
	{
		int x;	///< Coordenada de destino x.
		int y;	///< Coordenada de destino y.
		int rsombra_x;	///< Posición de la sombra en el eje de abcisas.
		int rsombra_y;	///< Posición de la sombra en el eje de ordenadas.
		float hipotenusa;	///< Hipotenusa del triángulo de desplazamiento.
		float puntos_generados;	///< Puntos del desplazamiento generados.
		float incremento_curva;	///< Valor del incremento de la curva de efecto.
		float curva;	///< Valor total de la curva de efecto.
		float angulo;	///< Ángulo del triángulo de desplazamiento.
		float angulo_de_desvio;	///< Ángulo de efecto.
		float coseno_desvio;	///< Coseno del triángulo del efecto.
		float seno_desvio;	///< Seno del triángulo del efecto.
		int velocidad;	///< Velocidad del desplazamiento.
	};

/*! \class Jugador
    \brief Datos del Jugador que participa en una Partida.
 */
	struct Jugador
	{
		std::string nombre_;	///< Nombre del Jugador.
		int tipo_;	///< Tipo del Jugador.
		int color_;	///< Color del Jugador.
		int equipo_;	///< Equipo del Jugador.
	};

/*! \class Campo
    \brief Datos del Campo en el que se desarrolla una Partida.
 */	
	struct Campo
	{
		std::string nombre_;	///< Nombre del Campo.
		std::string hoyo_;	///< Número de hoyo del Campo.
		std::string par_;	///< Par del Campo.
		SDL_Rect posicion_salida_;	///< Posición de salida de los jugadores.
		SDL_Rect posicion_hoyo_;	///< Posición del hoyo del Campo.
		std::string colores_;	///< Fichero de colores de colisión.
		std::string animaciones_;	///< Directorio de animaciones.
		std::string ruta_;	///< Ruta a las imágenes del Campo.
	};
}

#endif
