/// \file humano.h Humano.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _HUMANO_H_
#define _HUMANO_H_

#include "jugador.h"

/*! \class Humano
    \brief Jugador controlado por una persona.

		Esta clase se encarga de la implementación de un jugador controlado
		por una persona.
		
		Todos los jugadores tienen un nombre, un color y
		pueden pertenecer a un equipo cuando se está jugando una partida por
		parejas.
		
		De la misma forma, los jugadores de un mismo equipo podrán
		compartir la bola de golf. A parte de esto, el jugador cuenta con una
		lista de palos de golf que podrá utilizar durante la partida.
 */
class Humano: public Jugador
{
	public:

		/*! Realiza las asociaciones con la Partida y la Pantalla.\n
				Establece el nombre y el color del jugador. Carga las imágenes
				y crea la lista de palos. Genera las animaciones del jugador.
				\brief Constructor.
				\param nombre Nombre del Jugador.
				\param color Color del Jugador.
				\param bola Bola del Jugador.
				\param partida Partida que se está desarrollando.
				\param pantalla Pantalla donde se dibujará la Bola.
		 */
		Humano(std::string nombre, int color, Bola& bola, Partida *partida,
			Pantalla *pantalla);
	
		/*! El Jugador realiza un lanzamiento de la Bola golpeándola con el Palo.
				\brief Golpea la Bola.
				\return \b 0 cuando el lanzamiento ha finalizado.
				\see Palo::AlcanceMaximo.
				\see Palo::AnguloSalida.
				\see Cursor::Angulo.
		 */		
		int GolpearBola();
};

#endif
