/// \file juego.cpp Juego.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <SDL/SDL.h>
#include <SDL/SDL_image.h>
#include <SDL/SDL_ttf.h>
#include <SDL/SDL_mixer.h>
#include <iostream>
#include "juego.h"
#include "menu.h"

Juego::Juego()
{
	// Inicializamos SDL.
	if(SDL_Init(SDL_INIT_VIDEO) < 0)
	{
		std::cerr << "Error al inicializar SDL:" << std::endl << SDL_GetError();
		exit(1);
	}

	// Al salir cerramos SDL.
	atexit(SDL_Quit);
	
	// Inicializamos la API para fuentes truetype.
	if(TTF_Init() < 0)
	{
		std::cerr << "Error al inicializar SDL_TFF:" << std::endl
		<< TTF_GetError();
		exit(1);
	}	

	// Cerramos la API.
	atexit(TTF_Quit);
	
	// Inicializamos el subsistema de audio.
	if(Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT,
	MIX_DEFAULT_CHANNELS, 4096) < 0) 
	{
		std::cerr << "Error al inicializar SDL_MIXER:" << std::endl
		<< Mix_GetError();
		exit(1);
	}	

	// Al salir, cerramos el subsistema de audio.
	atexit(Mix_CloseAudio);
}

Juego::~Juego()
{
	// Destruimos el menú del juego.
	delete menu_;
}

void Juego::Iniciar()
{	
	// Creamos y asociamos el menú del juego.
	menu_ = new Menu(&pantalla_);

	// Invocamos al menú principal.
	menu_ -> Principal();
}

