/// \file juego.h Juego.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _JUEGO_H_
#define _JUEGO_H_

#include "partida.h"
#include "menu.h"
#include "pantalla.h"

class Menu;


/*! \class Juego
    \brief Clase principal.

    Esta es la clase principal del juego.
    
    En ella, se inicializan los
    subsistemas de imagen, sonido y fuentes y se crea la pantalla
    en la que se dibujarán todos los elementos gráficos del juego.
 */
class Juego
{
	public:

		/*! Inicializa SDL, los subsistemas de sonido, imagen y fuentes.
				Crea el Menu y lo muestra.
				\brief Constructor.
		 */
		Juego();

		/*! Destruye el Menu.
				\brief Destructor.
		 */
		~Juego();

		/*! Inicia el juego invocando al Menu principal.
				\brief Inicia el juego.
				\see Menu::Principal.
		 */	
		void Iniciar();

	private:
	
		Menu *menu_;	///< Menu del Juego.
		
		Pantalla pantalla_;	///< Pantalla del Juego.
};

#endif
