/// \file menu.cpp Menú del juego.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <SDL/SDL.h>
#include <iostream>
#include <string>
#include <algorithm>
#include <map>
#include <tinyxml.h>
#include <fstream>
#include "menu.h"
#include "partida.h"
#include "practicar.h"
#include "matchplay.h"
#include "strokeplay.h"
#include "datos.h"
#include "utilidades.h"
#include "pantalla.h"
#include "rejilla.h"
#include "constantes.h"
#include "campo.h"
#include "jugador.h"

Menu::Menu(Pantalla *pantalla)
{
	// Inicializamos la generación pseudo-aleatoria de números.
	srand((unsigned)time(0));

	// Establecemos el número de jugadores.
	njugadores_ = 4;

	// Establecemos el número de colores.
	ncolores_ = 6;

	// Establecemos el número de tipos de jugadores.
	ntipos_ = 4;
	
	// Asociamos con la pantalla.
	pantalla_ = pantalla;

	// La partida no se ha iniciado. El puntero es nulo.
	partida_ = 0;
	
	rfondo_.x = 0;
	rfondo_.y = 0;
	rfondo_.w = pantalla_ -> Ancho();
	rfondo_.h = pantalla_ -> Alto();

	// Cadena temporal para la generación de rutas.
	//std::string tmp;
	
	// Cargamos la imagen del menú principal.
	principal_ = Utilidades::CargarImagen(RutaImagen("principal.png"));

	// Cargamos la imagen del selector.
	selector_ = Utilidades::CargarImagen(RutaImagen("bola_menu.png"));

	// Guardamos el ancho y el alto.
	rselector_.w = selector_ -> w;
	rselector_.h = selector_ -> h;	

	// Establecemos las coordenadas.
	rselector_.x = 0;
	rselector_.y = 0;

	// Cargamos la imagen del menú practicar.
	practicar_ = Utilidades::CargarImagen(RutaImagen("practicar.png"));
	
	// Cargamos la imagen del menú de elección de campo del modo practicar.
	practicar_campo_ =
		Utilidades::CargarImagen(RutaImagen("practicar_campo.png"));

	// Cargamos la imagen del menú matchplay.	
	matchplay_ = Utilidades::CargarImagen(RutaImagen("matchplay.png"));

	// Cargamos la imagen del menú de elección de campo del modo matchplay.
	matchplay_campo_ =
		Utilidades::CargarImagen(RutaImagen("matchplay_campo.png"));

	// Cargamos la imagen del menú strokeplay.	
	strokeplay_ = Utilidades::CargarImagen(RutaImagen("strokeplay.png"));

	// Cargamos la imagen del menú de elección de campo del modo strokeplay.
	strokeplay_campo_ =
		Utilidades::CargarImagen(RutaImagen("strokeplay_campo.png"));

	// Las imagenes de los textos de los nombres de los jugadores son nulas.
	for(int x = 0; x < njugadores_; x++)	
		sjugadores_.push_back(0);
	
	// Creamos los rectángulos de posición para los nombres de los jugadores.
	for(int x = 0; x < njugadores_; x++)
		rjugadores_.push_back(SDL_Rect());

	// Creamos las cadenas de los nombres de los jugadores.		
	for(int x = 0; x < njugadores_; x++)
		jugadores_.push_back(std::string());		

	// Las imagenes de los textos de los tipos de los jugadores son nulas.
	for(int x = 0; x < ntipos_; x++)
		stipos_.push_back(0);

	// Creamos los rectángulos de posición para los tipos de los jugadores.
	for(int x = 0; x < ntipos_; x++)
		rtipos_.push_back(SDL_Rect());

	// Creamos los tipos de los jugadores.
	for(int x = 0; x < ntipos_; x++)
		tipos_.push_back(-1);	

	// Creamos los rectángulos de posición para los colores de los jugadores.
	for(int x = 0; x < ncolores_; x++)
		rcolores_.push_back(SDL_Rect());

	// Creamos los colores de los jugadores.
	for(int x = 0; x < ncolores_; x++)
		colores_.push_back(-1);

	// Establecemos las coordenadas para los nombres de los jugadores.
	for(int x = 0; x < njugadores_; ++x)
	{
		rjugadores_[x].x = 128;
		rjugadores_[x].y = 128 + 64 * x;
		rjugadores_[x].w = 206;
		rjugadores_[x].h = 40;
	}

	// Establecemos las coordenadas para los tipos de los jugadores.
	for(int x = 0; x < njugadores_; ++x)
	{
		rtipos_[x].x = 398;
		rtipos_[x].y = 128 + 64 * x;
		rtipos_[x].w = 130;
		rtipos_[x].h = 40;
	}

	// Establecemos las coordenadas para los colores de los jugadores.
	for(int x = 0; x < njugadores_; ++x)
	{
		rcolores_[x].x = 608;
		rcolores_[x].y = 136 + 64 * x;
		rcolores_[x].w = 24;
		rcolores_[x].h = 24;
	}
	
	// Cargamos la rejilla de los colores de los jugadores.
	rejilla_colores_ = new Rejilla(RutaImagen("colores.png"), 1, 6);
	
	// Todavía no mostramos imágenes del campo. Los punteros son nulos.
	imagen_hoyo_ = 0;
	nombre_campo_ = 0;
	numero_hoyo_ = 0;
	
	// 120 x 170
	// borde
	// sombra arrojada 2
	
	rimagen_hoyo_.x = 327;
	rimagen_hoyo_.y = 101;

	// Cargamos la imagen del menú de pausa.
	pausa_ = Utilidades::CargarImagen(RutaImagen("pausa.png"));

	// Cargamos la imagen del recuadro de pausa.
	mpausa_ = Utilidades::CargarImagen(RutaImagen("mpausa.png"));

	// Guardamos el ancho y el alto.
	rmpausa_.w = mpausa_ -> w;
	rmpausa_.h = mpausa_ -> h;

	// Establecemos las coordenadas.
	rmpausa_.x = rfondo_.w / 2 - rmpausa_.w / 2;
	rmpausa_.y = rfondo_.h / 2 - rmpausa_.h / 2;

	// Cargamos la imagen del recuadro de la confirmación de salir.
	mseguro_ = Utilidades::CargarImagen(RutaImagen("mseguro.png"));

	// Guardamos el ancho y el alto.
	rmseguro_.w = mseguro_ -> w;
	rmseguro_.h = mseguro_ -> h;

	// Establecemos las coordenadas.
	rmseguro_.x = rmpausa_.x;
	rmseguro_.y = rmpausa_.y;

	// Cargamos la imagen de elección de pareja del modo matchplay.
	matchplay_pareja_ =
		Utilidades::CargarImagen(RutaImagen("matchplay_pareja.png"));

	// Cargamos la imagen del tipo de juego del modo matchplay.
	matchplay_modo_ =
		Utilidades::CargarImagen(RutaImagen("matchplay_modo.png"));

	// Cargamos la imagen de la finalización del modo practicar.
	practicar_final_ =
		Utilidades::CargarImagen(RutaImagen("practicar_final.png"));

	// Cargamos la imagen de la finalización del modo matchplay.
	matchplay_final_ =
		Utilidades::CargarImagen(RutaImagen("matchplay_final.png"));

	// Cargamos la la imagen de la finalización del modo strokeplay.
	strokeplay_final_ =
		Utilidades::CargarImagen(RutaImagen("strokeplay_final.png"));

	// Cargamos la imagen del menú acerca de.
	acercade_ = Utilidades::CargarImagen(RutaImagen("acercade.png"));

	// Cargamos la imagen del menú de opciones.
	opciones_ = Utilidades::CargarImagen(RutaImagen("opciones.png"));

	// Cargamos la imagen de los controles del juego.
	controles_ = Utilidades::CargarImagen(RutaImagen("controles.png"));

	// Los punteros a las imágenes de los textos del menú de opciones son nulos.
	tefectos_ = 0;
	tmusica_ = 0;
	tcontroles_ = 0;

	// Los punteros a las imágenes de los textos de elección de pareja
	// son nulos.
	for(int x = 0; x < 4; ++x)
		stexto_pareja_.push_back(0);
		
	for(int x = 0; x < 4; ++x)
		rtexto_pareja_.push_back(SDL_Rect());

	// Los punteros a las imágenes de los textos de elección de modo de juego
	// son nulos.
	bolas_compartidas_ = 0;
	bolas_independientes_ = 0;

	// Cargamos los efectos de sonido.
	seleccionar_.Cargar(RutaSonido("seleccionar.ogg").c_str());
	aceptar_.Cargar(RutaSonido("continuar.ogg").c_str());
	cancelar_.Cargar(RutaSonido("volver.ogg").c_str());
	cambiar_.Cargar(RutaSonido("cambiar.ogg").c_str());

	// Cargamos la música.
	musica_fondo_.Cargar("./snd/musica/menu.ogg");
	
	// Activamos la música y los efectos.
	efectos_ = true;
	musica_ = true;
	
	// Leemos las opciones.
	this -> LeerOpciones();

	// Abrimos el fichero de nombres.
	std::ifstream nombres;
	nombres.open("./cfg/nombres", std::ifstream::in);
	
	if(nombres == 0)
	{
		std::cerr << "Menu::Menu() Error: No se puede abrir el fichero nombres."
			<< std::endl;
		exit(1);
	}

	// Obtenemos la longitud del fichero.
  nombres.seekg(0, std::ios::end);
  longitud_ = nombres.tellg();
	nombres.seekg(0, std::ios::beg);
	
	// Creamos un vector con la longitud del fichero.
	fichero_ = new char[longitud_];

	// Copiamos el fichero a memoria.
	nombres.read(fichero_, longitud_);

	// Cerramos el fichero.
	nombres.close();
}

void Menu::LeerOpciones()
{
	// Documento xml.
	TiXmlDocument opciones;

	// Cargamos el fichero de opciones.
	if(!opciones.LoadFile("./cfg/opciones.xml"))
	{
		std::cerr << "Menu::LeerOpciones() Error: No se puede abrir opciones.xml."
			<< std::endl;
	}

	// Establecemos la raíz del documento.
	TiXmlElement *raiz = opciones.RootElement();

	// Establecemos la opción.
	TiXmlElement *opcion = raiz -> FirstChildElement();
	
	// Recuperamos el valor para la opción de los efectos.
	std::string valor = opcion -> Attribute("efectos");

	// Activamos o desactivamos los efectos de sonido.
	if(valor == "si")
		efectos_ = true;
	else
		efectos_ = false;

	// Recuperamos el valor para la opción de música.
	valor = opcion -> Attribute("musica");

	// Activamos o desactivamos la música del juego.		
	if(valor == "si")
		musica_ = true;
	else
		musica_ = false;
}

void Menu::GuardarOpciones()
{
	// Documento xml.
	TiXmlDocument opciones;

	// Abrimos el fichero de opciones.
	if(!opciones.LoadFile("./cfg/opciones.xml"))
	{
		std::cerr << "Menu::LeerOpciones() Error: No se puede abrir opciones.xml."
			<< std::endl;
	}

	// Establecemos la raíz del documento.
	TiXmlElement *raiz = opciones.RootElement();

	// Establecemos la opción.
	TiXmlElement *opcion = raiz -> FirstChildElement();

	// Escribimos el valor del atributo efectos en el fichero de opciones
	if(efectos_)
		opcion -> SetAttribute("efectos", "si");
	else
		opcion -> SetAttribute("efectos", "no");	

	// Escribimos el valor del atributo música en el fichero de opciones
	if(musica_)
		opcion -> SetAttribute("musica", "si");
	else
		opcion -> SetAttribute("musica", "no");

	// Guardamos el fichero de opciones.
	if(!opciones.SaveFile("./cfg/opciones.xml"))
	{
		std::cerr << "Menu::GuardarOpciones() Error: No se puede guardar"
			<< " opciones.xml." << std::endl;
	}
}

Menu::~Menu()
{

	// Destruimos la imagen del selector.
	SDL_FreeSurface(selector_);

	// Destruimos la imagen del menú principal.
	SDL_FreeSurface(principal_);

	// Destruimos las imágenes de los modos de juego.
	SDL_FreeSurface(practicar_);
	SDL_FreeSurface(practicar_campo_);
	SDL_FreeSurface(matchplay_);
	SDL_FreeSurface(matchplay_campo_);
	SDL_FreeSurface(strokeplay_);
	SDL_FreeSurface(strokeplay_campo_);
	SDL_FreeSurface(practicar_final_);
	SDL_FreeSurface(matchplay_final_);
	SDL_FreeSurface(strokeplay_final_);

	// Destruimos las imágenes de los modos de juego de matchplay.
	SDL_FreeSurface(matchplay_pareja_);
	SDL_FreeSurface(matchplay_modo_);

//	SDL_FreeSurface(texto_pareja_);
//	SDL_FreeSurface(pareja1_);
//	SDL_FreeSurface(pareja2_);
//	SDL_FreeSurface(pareja3_);
//	SDL_FreeSurface(pareja_nadie_);

	for(int x = 0; x < 4; ++x)
		SDL_FreeSurface(stexto_pareja_[x]);

	SDL_FreeSurface(bolas_compartidas_);
	SDL_FreeSurface(bolas_independientes_);

	// Destruimos las imágenes del menú de elección de campo.
	SDL_FreeSurface(imagen_hoyo_);
	SDL_FreeSurface(nombre_campo_);
	SDL_FreeSurface(numero_hoyo_);

	// Destruimos las imágenes del menú de pausa.
	SDL_FreeSurface(pausa_);
	SDL_FreeSurface(mpausa_);
	SDL_FreeSurface(mseguro_);

	// Destruimos la imagen del menú acerca de.
	SDL_FreeSurface(acercade_);

	// Destruimos las imágenes del menú de opciones.
	SDL_FreeSurface(opciones_);
	SDL_FreeSurface(tefectos_);
	SDL_FreeSurface(tmusica_);
	SDL_FreeSurface(tcontroles_);
	SDL_FreeSurface(controles_);

	// Destruimos las imágenes de los textos de los nombres de los jugadores.
	for(int x = 0; x < njugadores_; ++x)
	{
		if(sjugadores_[x] != 0)
			SDL_FreeSurface(sjugadores_[x]);
	}
	
	// Destruimos las imágenes de los tipos de los jugadores.	
	for(int x = 0; x < ntipos_; ++x)
	{
		if(stipos_[x] != 0)
			SDL_FreeSurface(stipos_[x]);
	}	

	// Destruimos las imágenes de los tipos de los jugadores.		
	delete rejilla_colores_;
	
	// Si la partida no ha sido destruida, la destruimos.
	if(partida_ != 0)
		delete partida_;
	
	// Destruimos el vector donde copiamos el fichero de nombres.
	delete[] fichero_;
}


void Menu::DibujarElegirJugadores(int modo) const
{
	// Elegimos el modo de juego y dibujamos el fondo corresondiente.
	switch(modo)
	{
		case PRACTICAR:
			pantalla_ -> DibujarDirectamente(practicar_, &rfondo_);
			break;

		case MATCHPLAY:
			pantalla_ -> DibujarDirectamente(matchplay_, &rfondo_);
			break;
					
		case STROKEPLAY:
			pantalla_ -> DibujarDirectamente(strokeplay_, &rfondo_);
			break;
	}

	// Dibujamos el selector.
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);

	// Recorremos los nombres, tipos y colores de los jugadores.
	for(int x = 0; x < njugadores_; x++)
	{
		// Dibujamos los nombres que no sean nulos.
		if(sjugadores_[x] != 0)
		{
			SDL_Rect destino;
		
			destino.x = (rjugadores_[x].x + rjugadores_[x].w / 2)
				- (sjugadores_[x] -> w / 2);
			destino.y = (rjugadores_[x].y + rjugadores_[x].h / 2)
				- (sjugadores_[x] -> h / 2);
			
			pantalla_ -> DibujarDirectamente(sjugadores_[x], &destino);
		}

		// Dibujamos los tipos que no sean nulos.
		if(stipos_[x] != 0)
		{
			SDL_Rect destino;
		
			destino.x = (rtipos_[x].x + rtipos_[x].w / 2)
				- (stipos_[x] -> w / 2);
			destino.y = (rtipos_[x].y + rtipos_[x].h / 2)
				- (stipos_[x] -> h / 2);
			
			pantalla_ -> DibujarDirectamente(stipos_[x], &destino);
		}

		// Dibujamos los colores que sean válidos.
		if(colores_[x] != -1)
		{
			SDL_Rect destino;
			
			rejilla_colores_ -> SeleccionarCuadro(colores_[x]);
		
			destino.x = (rcolores_[x].x + rcolores_[x].w / 2)
				- (rejilla_colores_ -> Posicion().w / 2);
			destino.y = (rcolores_[x].y + rcolores_[x].h / 2)
				- (rejilla_colores_ -> Posicion().h / 2);
			
			pantalla_ -> DibujarDirectamente(rejilla_colores_ -> Imagen(),
				&(rejilla_colores_ -> Posicion()), &destino);		
		}
	} // for
}

void Menu::DibujarElegirPareja() const
{
	// Dibujamos los textos.
	pantalla_ -> DibujarDirectamente(matchplay_pareja_, &rfondo_);
	pantalla_ -> DibujarDirectamente(stexto_pareja_[0], &rtexto_pareja_[0]);
	pantalla_ -> DibujarDirectamente(stexto_pareja_[1], &rtexto_pareja_[1]);
	pantalla_ -> DibujarDirectamente(stexto_pareja_[2], &rtexto_pareja_[2]);
	pantalla_ -> DibujarDirectamente(stexto_pareja_[3], &rtexto_pareja_[3]);

	// Dibujamos el selector.
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);	
}

void Menu::DibujarElegirModoMatchplay() const
{
	// Dibujamos el fondo y los textos del modo de juego.
	pantalla_ -> DibujarDirectamente(matchplay_modo_, &rfondo_);
	pantalla_ -> DibujarDirectamente(bolas_compartidas_, &rbolas_compartidas_);
	pantalla_ -> DibujarDirectamente(bolas_independientes_,
		&rbolas_independientes_);

	// Dibujamos el selector.
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);	
}

void Menu::DibujarElegirCampo(int modo) const
{
	// Elegimos el modo y dibujamos el fondo correspondiente.
	switch(modo)
	{
		case PRACTICAR:
			pantalla_ -> DibujarDirectamente(practicar_campo_, &rfondo_);
			break;

		case MATCHPLAY:
			pantalla_ -> DibujarDirectamente(matchplay_campo_, &rfondo_);
			break;
					
		case STROKEPLAY:
			pantalla_ -> DibujarDirectamente(strokeplay_campo_, &rfondo_);
			break;
	}

	// Dibujamos la imagen del hoyo.
	pantalla_ -> DibujarDirectamente(imagen_hoyo_, &rimagen_hoyo_);

	// Dibujamos el nombre del campo.
	pantalla_ -> DibujarDirectamente(nombre_campo_, &rnombre_campo_);

	// Si estamos en el modo practicar dibujamos el número de hoyo.
	if(modo == PRACTICAR)
		pantalla_ -> DibujarDirectamente(numero_hoyo_, &rnumero_hoyo_);

	// Dibujamos el selector.
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);	
}

void Menu::DibujarPrincipal() const
{
	// Dibujamos la imagen de fondo del menú principal.
	pantalla_ -> DibujarDirectamente(principal_, &rfondo_);

	// Dibujamos el selector.
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);
}

void Menu::DibujarAcercaDe() const
{
	// Dibujamos la imagen de fondo del menú acerca de.
	pantalla_ -> DibujarDirectamente(acercade_, &rfondo_);

	// Dibujamos el selector.
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);
}

int Menu::Finalizar(int modo)
{
	// Copiamos las puntuaciones de la partida.
	std::vector<int> puntuaciones = partida_ -> Puntuaciones();

	// Si la música está activada y no está sonando, la reproducimos.
	if(musica_)
		if(!musica_fondo_.Reproduciendo())
			musica_fondo_.Reproducir(1);

	// Imagen para el texto del encabezado.
	SDL_Surface *encabezado = 0;

	// Rectángulo de posición para el texto del encabezado.
	SDL_Rect rencabezado;

	// Elegimos el modo y creamos el encabezado.
	switch(modo)
	{
		case PRACTICAR:
		{
			// Creamos el texto del encabezado.
			encabezado = Utilidades::CrearTexto("FINAL DE LA PRACTICA",
				Constantes::_FUENTE_, 34,
				Utilidades::Color(Utilidades::BLANCO));

			break;
		}

		case MATCHPLAY:
		{
			// Cadenas para los nombres de los ganadores.
			std::string nombre1, nombre2;

			// Cadena para el encabezado.
			std::string sencabezado;
	
			// El número de jugadores es 2.
			if(partida_ -> Jugadores().size()/*jugadores.size()*/ == 2)
			{	
				// Obtenemos los nombres.
				nombre1 = partida_ -> Jugadores()[0] -> Nombre();
				nombre2 = partida_ -> Jugadores()[1] -> Nombre();
	
				// Generamos el encabezado con el jugador ganador o con el empate.
				if(puntuaciones[1] < puntuaciones[0])
					sencabezado = nombre1 + " HA GANADO";
				else if(puntuaciones[0] < puntuaciones[1])
					sencabezado = nombre2 + " HA GANADO";
				else
					sencabezado = nombre1 + " Y " + nombre2 + " HAN EMPATADO";
			}
			else
			{
				// El primer equipo es el ganador.
				if(puntuaciones[1] < puntuaciones[0])
				{
					// Recorremos la lista de jugadores.
					for(std::vector<Jugador*>::const_iterator i = partida_
						-> Jugadores().begin(); i != partida_ -> Jugadores().end(); ++i)
					{
						// Guardamos los nombres del primer.
						if((*i) -> Equipo() == 0)
						{
							if(nombre1.empty())
								nombre1 = (*i) -> Nombre();
							else
								nombre2 = (*i) -> Nombre();
						}
					}
			
					// El equipo tiene dos miembros.
					if(!nombre2.empty())
						sencabezado = nombre1 + " Y " + nombre2 + " HAN GANADO";

					// El equipo tiene un único miembro.
					else
						sencabezado = nombre1 + " HA GANADO";				
				}

				// El segundo equipo es el ganador.
				else if(puntuaciones[0] < puntuaciones[1])
				{
					// Recorremos la lista de jugadores.
					for(std::vector<Jugador*>::const_iterator i = partida_ ->
						Jugadores().begin(); i != partida_ -> Jugadores().end(); ++i)
					{
						// Guardamos los nombres del segundo equipo.
						if((*i) -> Equipo() == 1)
						{
							if(nombre1.empty())
								nombre1 = (*i) -> Nombre();
							else
								nombre2 = (*i) -> Nombre();
						}
					}

					// El equipo tiene dos miembros.
					if(!nombre2.empty())
						sencabezado = nombre1 + " Y " + nombre2 + " HAN GANADO";

					// El equipo tiene un único miembro.
					else
						sencabezado = nombre1 + " HA GANADO";				
				}
				// Los equipos han empatado.
				else
				{
					sencabezado = "LOS EQUIPOS HAN EMPATADO";
				}
			}

			// Convertimos a mayúsculas.
			std::transform(sencabezado.begin(), sencabezado.end(),
				sencabezado.begin(), ::toupper);

			// Creamos el texto del encabezado.	
			encabezado = Utilidades::CrearTexto(sencabezado.c_str(),
				Constantes::_FUENTE_, 34,
				Utilidades::Color(Utilidades::BLANCO));

			break;
		}

		case STROKEPLAY:
		{

			// Cadena para el encabezado.
			std::string sencabezado;

			// Hay un único jugador.
			if(partida_ -> Jugadores().size() == 1)
				sencabezado = "LA PARTIDA HA FINALIZADO";
	
			// Hay más de un jugador.
			else
			{
				// Elegimos el primer valor como mínimo.
				int minimo = puntuaciones[0];
	
				// Comparamos con todas las puntuaciones para obtener el mínimo
				// global.
				for(unsigned int x = 0; x < partida_ -> Jugadores().size(); ++x)
					if(puntuaciones[x] < minimo)
						minimo = puntuaciones[x];

				// Establecemos el número de jugadores que poseen esa puntuación
				// a 0.
				int numero_jugadores_minimo = 0;

				// Contamos cuantos jugadores poseen esa puntación.
				for(unsigned int x = 0; x < partida_ -> Jugadores().size(); ++x)
					if(puntuaciones[x] == minimo)
						++numero_jugadores_minimo;

				// Hay varios jugadores con dicha puntuación.
				if(numero_jugadores_minimo > 1)
					sencabezado = "VARIOS JUGADORES HAN EMPATADO";

				// Hay un único jugador que ha ganado.
				else
				{
					// Cadena para el nombre del jugador.
					std::string nombre;

					// Buscamos su nombre.
					for(unsigned int x = 0; x < partida_ -> Jugadores().size(); ++x)
						if(puntuaciones[x] == minimo)
							nombre = partida_ -> Jugadores()[x] -> Nombre();

					// Generamos el encabezado.
					sencabezado = nombre + " HA GANADO";
				}
			}

			// Lo convertimos a mayúsculas.
			std::transform(sencabezado.begin(), sencabezado.end(),
				sencabezado.begin(), ::toupper);

			// Creamos la imagen del texto del encabezado.
			encabezado = Utilidades::CrearTexto(sencabezado.c_str(),
				Constantes::_FUENTE_, 34,
				Utilidades::Color(Utilidades::BLANCO));

			break;
		}
	}

	// Guardamos el ancho y el alto de la imagen.
	rencabezado.w = encabezado -> w;
	rencabezado.h = encabezado -> h;

	// Establecemos las coordenadas.
	rencabezado.x = pantalla_ -> Ancho() / 2 - rencabezado.w / 2;
	rencabezado.y = 111;

	// Imagen para el texto del título.	
	SDL_Surface *titulo = 0;

	// Rectángulo de posición para el texto del título.
	SDL_Rect rtitulo;


	// Elegimos el modo y creamos el título.
	switch(modo)
	{	
		case PRACTICAR:
		{
			// Generamos la cadena para el título.
			std::string tmp = datos_campos_[0].nombre_ + " - Hoyo " +
				datos_campos_[0].hoyo_ + " (PAR " + datos_campos_[0].par_ + ")";

			// Creamos el texto del título.	
			titulo = Utilidades::CrearTexto(tmp.c_str(), Constantes::_FUENTE_, 28,
				Utilidades::Color(Utilidades::BLANCO));

			break;
		}

		case MATCHPLAY:
		{
			// Convertimos el número de hoyos a string.
			std::stringstream ss;
			ss << datos_campos_.size();
			std::string numero_hoyos = ss.str();

			// Cadena para el título.	
			std::string tmp;
	
			// Seleccionamos si el campo tiene uno o más hoyos.
			if(atoi(numero_hoyos.c_str()) > 1)
				tmp = datos_campos_[0].nombre_ + " (" + numero_hoyos + " Hoyos)";
			else
				tmp = datos_campos_[0].nombre_ + " (" + numero_hoyos + " Hoyo)";	

			// Generamos la cadena para el título.	
			titulo = Utilidades::CrearTexto(tmp.c_str(), Constantes::_FUENTE_, 28,
				Utilidades::Color(Utilidades::BLANCO));

			break;
		}

		case STROKEPLAY:
		{
			// Calculamos el par total del campo.
			int par_total = 0;
			for(unsigned int x = 0; x < datos_campos_.size(); ++x)
				par_total = par_total + atoi(datos_campos_[x].par_.c_str());

			// Convertimos el par total a string.
			std::stringstream ss;
			ss << par_total;
			std::string par_campo = ss.str();

			// Generamos la cadena del título.
			std::string tmp = datos_campos_[0].nombre_ + " (PAR " + par_campo + ")";

			// Creamos la imagen del texto del título.
			titulo = Utilidades::CrearTexto(tmp.c_str(), Constantes::_FUENTE_, 28,
				Utilidades::Color(Utilidades::BLANCO));

			break;
		}

	} // switch

	// Guardamos el ancho y el alto de la imagen.
	rtitulo.w = titulo -> w;
	rtitulo.h = titulo -> h;

	// Establecemos las coordenadas.
	rtitulo.x = pantalla_ -> Ancho() / 2 - rtitulo.w / 2;
	rtitulo.y = 160;


	// Valor de referencia para la coordenada y en los nombres.
	int referenciay = 160;

	// Lista de las imágenes de los nombres de los jugadores.
	std::vector<SDL_Surface*> lista;

	// Lista de rectángulos de posición de los nombres de los jugadores.
	std::vector<SDL_Rect> rlista;
	
	// Creamos las imágenes con los nombres de los jugadores y su par.
	for(std::vector<Jugador*>::const_iterator i = partida_
		-> Jugadores().begin(); i != partida_ -> Jugadores().end(); ++i)
	{
		// El puntero es nulo antes de crear la imagen.
		lista.push_back(0);


			switch(modo)
			{
				case PRACTICAR:
				{
					// Convertimos el par a string.
					std::stringstream ss;
					ss << (*i) -> Par();
					std::string par = ss.str();

					// Creamos la cadena para las puntuaciones.
					std::string tmp = (*i) -> Nombre() + " (PAR " + par + ")";

					// Creamos la imagen del texto.
					lista.back() = Utilidades::CrearTexto(tmp.c_str(),
						Constantes::_FUENTE_, 28,
						Utilidades::Color(Utilidades::BLANCO));

					break;
				}
				case MATCHPLAY:
				{
					// Convertimos las puntuaciones a string.
					std::stringstream ss;
					ss << puntuaciones[(*i) -> Equipo()];
					std::string puntuacion = ss.str();
		
					// Creamos la cadena para las puntuaciones.
					std::string tmp = (*i) -> Nombre() + " (+" + puntuacion + ")";

					// Creamos la imagen del texto.
					lista.back() = Utilidades::CrearTexto(tmp.c_str(),
					Constantes::_FUENTE_, 28,
					Utilidades::Color(Utilidades::BLANCO));

					break;
				}

				case STROKEPLAY:
				{
					// Convertimos las puntuaciones a string.
					std::stringstream ss;
					ss << puntuaciones[(*i) -> Equipo()];
					std::string puntuacion = ss.str();

					// Cadena para las puntuaciones.
					std::string tmp;

					// Si la puntuación es positiva o 0 el signo es +.
					if(puntuaciones[(*i) -> Equipo()] >= 0)
						tmp = (*i) -> Nombre() + " (+" + puntuacion + ")";

					// Si es negativa, el signo es -.
					else
						tmp = (*i) -> Nombre() + " (" + puntuacion + ")";

					// Creamos la imagen del texto.
					lista.back() = Utilidades::CrearTexto(tmp.c_str(),
						Constantes::_FUENTE_, 28,
						Utilidades::Color(Utilidades::BLANCO));

					break;
				}

			} // switch

		// Rectángulo de posición.
		SDL_Rect rtmp;

		// Guardamos el ancho y el alto de la imagen.
		rtmp.w = lista.back() -> w;
		rtmp.h = lista.back() -> h;

		// Establecemos las coordenadas.
		rtmp.x = pantalla_ -> Ancho() / 2 - rtmp.w / 2;
		rtmp.y = referenciay + 40;
		
		// Añadimos la posición a la lista.
		rlista.push_back(rtmp);
		
		// Aumentamos el índice de referencia de la coordenada y.
		referenciay += 40;

	} // for


	// Establecemos las coordenadas del selector.
	rselector_.x = 612;
	rselector_.y = 425;

	// Dibujamos el fondo determinado por el modo.
	if(modo == PRACTICAR)
		pantalla_ -> DibujarDirectamente(practicar_final_, &rfondo_);
	else if(modo == MATCHPLAY)
		pantalla_ -> DibujarDirectamente(matchplay_final_, &rfondo_);
	else if(modo == STROKEPLAY)
		pantalla_ -> DibujarDirectamente(strokeplay_final_, &rfondo_);

	// Dibujamos los textos.
	pantalla_ -> DibujarDirectamente(encabezado, &rencabezado);
	pantalla_ -> DibujarDirectamente(titulo, &rtitulo);
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);	
	
	// Dibujamos la lista de jugadores.
	for(unsigned int x = 0; x < lista.size(); ++x)
		pantalla_ -> DibujarDirectamente(lista[x], &rlista[x]);		
	
	// Actualizamos pantalla.
	pantalla_ -> Actualizar();

	// Variables de tiempo para el control del bucle.
	Uint32 ta_for, tb_for;

	// Variables de tiempo para el control de la cola de eventos.
	Uint32 ta_while, tb_while;

	// Evento a procesar.
	SDL_Event evento;

	// Tecla del evento.
	SDLKey &tecla = evento.key.keysym.sym;

	// Variable de control para la continuación del menú.
	bool terminar = false;

	// Variable de control para salir del juego.
	bool salir = false;

	for(;;)
	{
		// Guardamos el tiempo para el control del bucle.
		ta_for = SDL_GetTicks();

		// Si la música está activada y no está sonando, la reproducimos.		
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Bucle de la cola de eventos.
		while(SDL_PollEvent(&evento))
		{
			// Guardamos el tiempo para el control del bucle de la cola de eventos.
			ta_while = SDL_GetTicks();
			
			// Si el evento es salir, terminamos el juego.
			if(evento.type == SDL_QUIT)
				salir = true;		

			// Se ha pulsado una tecla.
			if(evento.key.type == SDL_KEYDOWN)
			{
				// Pantalla completa.
				if(tecla == teclado_.Tecla(Teclado::PANTALLA_COMPLETA))
					pantalla_ -> PantallaCompleta();

				// Continuamos al siguiente menú.
				if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
				{
					if(efectos_)
						aceptar_.Reproducir();
					terminar = true;
				}
			}

			// Guardamos el tiempo.
			tb_while = SDL_GetTicks();
		
			// Si el tiempo transcurrido es menor que el establecido, esperamos.
			if(tb_while - ta_while < Constantes::_MS_)
				SDL_Delay(Constantes::_MS_ - (tb_while - ta_while));

		}
		
		// Si hemos terminado o hemos salido, rompemos el bucle.
		if(terminar || salir)
			break;
		
		// Obtenemos el tiempo.
		tb_for = SDL_GetTicks();

		// Si el tiempo transcurrido es menor que el establecido, esperamos.	
		if(tb_for - ta_for < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb_for - ta_for));

	}

	// Destruimos las imágenes de encabezado y título.
	SDL_FreeSurface(encabezado);
	SDL_FreeSurface(titulo);

	// Destruimos las imágenes de los nombres de los jugadores.
	for(std::vector<SDL_Surface*>::iterator i = lista.begin();
		i != lista.end(); ++i)
		SDL_FreeSurface(*i);;

	// Salimos o continuamos.
	if(salir)
		return -1;
	else
		return 0;

}

void Menu::DibujarOpciones() const
{
	// Dibujamos el fondo y las imágenes de los textos.
	pantalla_ -> DibujarDirectamente(opciones_, &rfondo_);
	pantalla_ -> DibujarDirectamente(tefectos_, &rtefectos_);
	pantalla_ -> DibujarDirectamente(tmusica_, &rtmusica_);
	pantalla_ -> DibujarDirectamente(tcontroles_, &rtcontroles_);		
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);
}


int Menu::Opciones()
{
	// Si la música está activada y no está sonando, la reproducimos.	
	if(musica_)
		if(!musica_fondo_.Reproduciendo())
			musica_fondo_.Reproducir(1);

	// Lista de opciones.
	enum {ACEPTAR, EFECTOS, MUSICA, CONTROLES, PANTALLA_CONTROLES};

	// Destruimos las imágenes de los textos.
	SDL_FreeSurface(tefectos_);
	SDL_FreeSurface(tmusica_);
	SDL_FreeSurface(tcontroles_);
	
	// Los efectos están activados. Creamos la imagen del texto.
	if(efectos_)
		tefectos_ = Utilidades::CrearTexto("Efectos activados",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

	// Los efectos están desactivados. Creamos la imagen del texto.
	else
		tefectos_ = Utilidades::CrearTexto("Sin efectos",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

	// La música está activada. Creamos la imagen del texto.
	if(musica_)
		tmusica_ = Utilidades::CrearTexto("Musica activada",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

	// La música está desactivada. Creamos la imagen del texto.
	else
		tmusica_ = Utilidades::CrearTexto("Sin musica",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));	

	// Texto para los controles.
	tcontroles_ = Utilidades::CrearTexto("Ver controles",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

	// Establecemos las coordenadas para el texto de los efectos.
	rtefectos_.w = tefectos_ -> w;
	rtefectos_.h = tefectos_ -> h;
	rtefectos_.x = pantalla_ -> Ancho() / 2 - rtefectos_.w / 2;
	rtefectos_.y = 163;

	// Establecemos las coordenadas para el texto de la música.	
	rtmusica_.w = tmusica_ -> w;
	rtmusica_.h = tmusica_ -> h;
	rtmusica_.x = pantalla_ -> Ancho() / 2 - rtmusica_.w / 2;
	rtmusica_.y = rtefectos_.y + 64;

	// Establecemos las coordenadas para el texto de los controles.
	rtcontroles_.w = tcontroles_ -> w;
	rtcontroles_.h = tcontroles_ -> h;
	rtcontroles_.x = pantalla_ -> Ancho() / 2 - rtcontroles_.w / 2;
	rtcontroles_.y = rtmusica_.y + 64;

	// Referencia en el eje de las x para el encuadre.
	int xopciones = 267;

	// Establecemos las coordenadas para el selector.
	rselector_.x = xopciones;
	rselector_.y = rtefectos_.y + rtefectos_.h / 2 - rselector_.h / 2;

	// Establecemos la seleccion inicial.
	int seleccion = EFECTOS;

	// Dibujamos y actualizamos.
	this -> DibujarOpciones();
	pantalla_ -> Actualizar();

	// Variables de control de tiempo para el bucle.
	Uint32 ta_for, tb_for;

	// Varaibles de control de tiempo para el bucle de la cola de eventos.
	Uint32 ta_while, tb_while;
	
	// Evento a procesar.
	SDL_Event evento;

	// Tecla del evento.
	SDLKey &tecla = evento.key.keysym.sym;

	for(;;)
	{
		// Guardamos el tiempo para el control del bucle.
		ta_for = SDL_GetTicks();

		// Si la música está activada y no está sonando, la reproducimos.	
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Procesamos la cola de eventos.
		while(SDL_PollEvent(&evento))
		{
			// Guardamos el tiempo para el control del bucle de la cola de eventos.		
			ta_while = SDL_GetTicks();
	
			// Si cerramos la ventana terminamos el juego.
			if(evento.type == SDL_QUIT)
				return -1;

			// Se ha pulsado una tecla.
			if(evento.key.type == SDL_KEYDOWN)
			{
				// Pantalla completa.
				if(tecla == teclado_.Tecla(Teclado::PANTALLA_COMPLETA))
					pantalla_ -> PantallaCompleta();

				// Opción de abajo a la actual.
				if(tecla == teclado_.Tecla(Teclado::ABAJO))
				{
					switch(seleccion)
					{
						case EFECTOS:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();						

							// Cambiamos la selección.
							seleccion = MUSICA;

							// Establecemos las coordenadas del selector.
							rselector_.y = rtmusica_.y + rtmusica_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							break;
						}
				
						case MUSICA:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = CONTROLES;

							// Establecemos las coordenadas del selector.
							rselector_.y = rtcontroles_.y + rtcontroles_.h / 2
								- rselector_.h / 2;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							break;					
						}
						
						case CONTROLES:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = ACEPTAR;

							// Establecemos las coordenadas del selector.
							rselector_.x = 612;
							rselector_.y = 425;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							break;					
						}
					}

				}

				// Opción de arriba a la actual.
				if(tecla == teclado_.Tecla(Teclado::ARRIBA))
				{
					switch(seleccion)
					{
						case ACEPTAR:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = CONTROLES;

							// Establecemos las coordenadas del selector.
							rselector_.x = xopciones;
							rselector_.y = rtcontroles_.y + rtcontroles_.h / 2
								- rselector_.h / 2;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							break;						
						
						}
						case CONTROLES:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = MUSICA;

							// Establecemos las coordenadas del selector.
							rselector_.y = rtmusica_.y + rtmusica_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							break;						
						}
						case MUSICA:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = EFECTOS;

							// Establecemos las coordenadas del selector.
							rselector_.y = rtefectos_.y + rtefectos_.h / 2
								- rselector_.h / 2;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							break;								
						}
					}
				}

				// Aceptamos la selección.
				if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
				{
					switch(seleccion)
					{
						case ACEPTAR:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Guardamos las opciones.
							this -> GuardarOpciones();	

							// Continuamos al menú principal.
							return 0;
						}
						case EFECTOS:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								cambiar_.Reproducir();

							// Si los efectos están activos los desactivamos.
							if(efectos_)
								efectos_ = false;

							// Si los efectos están desactivados los activamos.
							else
								efectos_ = true;

							// Generamos le nuevo texto.
							if(efectos_)
								tefectos_ = Utilidades::CrearTexto("Efectos activados",
									Constantes::_FUENTE_, 24,
									Utilidades::Color(Utilidades::BLANCO));
							else
								tefectos_ = Utilidades::CrearTexto("Sin efectos",
									Constantes::_FUENTE_, 24,
									Utilidades::Color(Utilidades::BLANCO));							

							// Guardamos el ancho y el alto de la imagen.
							rtefectos_.w = tefectos_ -> w;
							rtefectos_.h = tefectos_ -> h;

							// Establecemos las coordenadas.
							rtefectos_.x = pantalla_ -> Ancho() / 2 - rtefectos_.w / 2;
							rtefectos_.y = 163;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							// Esperamos.
							SDL_Delay(Constantes::_MS_TECLA_);

							break;
						}
						case MUSICA:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								cambiar_.Reproducir();

							// Si la música está activa la paramos y la desactivamos.
							if(musica_)
							{
								Mix_HaltMusic();
								musica_ = false;
							}

							// Si la música está desactivada la reproducimos y la activamos.
							else
							{
								musica_fondo_.Reproducir(1);
								musica_ = true;
							}													

							// Generamos le nuevo texto.
							if(musica_)
								tmusica_ = Utilidades::CrearTexto("Musica activada",
									Constantes::_FUENTE_, 24,
									Utilidades::Color(Utilidades::BLANCO));
							else
								tmusica_ = Utilidades::CrearTexto("Sin musica",
									Constantes::_FUENTE_, 24,
									Utilidades::Color(Utilidades::BLANCO));

							// Guardamos el ancho y el alto de la imagen.
							rtmusica_.w = tmusica_ -> w;
							rtmusica_.h = tmusica_ -> h;

							// Establecemos las coordenadas.
							rtmusica_.x = pantalla_ -> Ancho() / 2 - rtmusica_.w / 2;
							rtmusica_.y = rtefectos_.y + 64;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();

							// Esperamos.
							SDL_Delay(Constantes::_MS_TECLA_);

							break;
						}
						case CONTROLES:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Cambiamos la selección.
							seleccion = PANTALLA_CONTROLES;

							// Establecemos las coordenadas del selector.
							rselector_.x = 612;
							rselector_.y = 425;	

							// Dibujamos.
							pantalla_ -> DibujarDirectamente(controles_, &rfondo_);
							pantalla_ -> DibujarDirectamente(selector_, &rselector_);
							pantalla_ -> Actualizar();

							break;
						}
						case PANTALLA_CONTROLES:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Cambiamos la selección.
							seleccion = EFECTOS;

							// Establecemos las coordenadas del selector.
							rselector_.x = xopciones;
							rselector_.y = rtefectos_.y + rtefectos_.h / 2
								- rselector_.h / 2;

							// Dibujamos.
							this -> DibujarOpciones();
							pantalla_ -> Actualizar();
								
							break;		
						}
					}
				}			
			}

			// Guardamos el tiempo para la cola de eventos.
			tb_while = SDL_GetTicks();

			// Si el tiempo transcurrido es menor al establecido, esperamos.
			if(tb_while - ta_while < Constantes::_MS_)
				SDL_Delay(Constantes::_MS_ - (tb_while-ta_while));
							
		} // while		

		// Guardamos el tiempo para el bucle.
		tb_for = SDL_GetTicks();

		// Si el tiempo transcurrido es menor al establecido, esperamos.
		if(tb_for - ta_for < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb_for - ta_for));

	} // for
}


int Menu::Principal()
{
	// Si la música está activada y no está sonando, la reproducimos.
	if(musica_)
		if(!musica_fondo_.Reproduciendo())
			musica_fondo_.Reproducir(1);

	// Lista de opciones.
	enum principal {PRACTICAR, MATCHPLAY, STROKEPLAY, OPCIONES,
		ACERCADE, SALIR, ACEPTAR};

	// Aplicamos el filtro de eventos.
	SDL_SetEventFilter(Utilidades::FiltroDeEventos);

	// Establecemos los valores para la repetición de teclas.
	SDL_EnableKeyRepeat(200, 10);
	
	// Establecemos las coordenadas del selector.
	rselector_.x = 532;
	rselector_.y = 111;

	// Establecemos la selección inicial.
	int seleccion = PRACTICAR;
	
	// Dibujamos.
	DibujarPrincipal();
	pantalla_ -> Actualizar();

	// Variables de control de tiempo para el bucle.
	Uint32 ta_for, tb_for;

	// Varaibles de control de tiempo para el bucle de la cola de eventos.
	Uint32 ta_while, tb_while;

	// Evento a procesar.
	SDL_Event evento;

	// Tecla del evento.
	SDLKey &tecla = evento.key.keysym.sym;

	for(;;)
	{
		// Guardamos el tiempo para el control del bucle.
		ta_for = SDL_GetTicks();

		// Si la música está activada y no está sonando, la reproducimos.	
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Procesamos la cola de eventos.
		while(SDL_PollEvent(&evento))
		{
			// Guardamos el tiempo para el control del bucle de la cola de eventos.
			ta_while = SDL_GetTicks();

			// Si cerramos la ventana terminamos el juego.
			if(evento.type == SDL_QUIT)
				return 0;

			// Se ha pulsado una tecla.
			if(evento.key.type == SDL_KEYDOWN)
			{
				// Pantalla completa.
				if(tecla == teclado_.Tecla(Teclado::PANTALLA_COMPLETA))
					pantalla_ -> PantallaCompleta();

				// Opción de abajo.
				if(tecla == teclado_.Tecla(Teclado::ABAJO))
				{
					if(seleccion != SALIR && seleccion != ACEPTAR)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Incrementamos la selección.
						++seleccion;

						// Establecemos las coordenadas del selector.
						rselector_.y = rselector_.y + 39;

						// Dibujamos.
						DibujarPrincipal();
						pantalla_ -> Actualizar();
					}
					
				}
				if(tecla == teclado_.Tecla(Teclado::ARRIBA))
				{
					if(seleccion != PRACTICAR && seleccion != ACEPTAR)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Decrementamos la selección.
						--seleccion;

						// Establecemos las coordenadas del selector.
						rselector_.y = rselector_.y - 39;

						// Dibujamos.
						DibujarPrincipal();
						pantalla_ -> Actualizar();
					}
					
				}

				// Aceptamos la selección.
				if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
				{

					// Si los efectos están activados, lo reproducimos.
					if(efectos_)
						aceptar_.Reproducir();

					switch(seleccion)
					{

						case PRACTICAR:
						{
							// Retorno de el menú de elección de jugadores.
							int retorno = ElegirJugadores(PRACTICAR);
							
							// Hemos cerrado la ventana. Terminamos el juego.
							if(retorno == -1)
								return 0;

							// Establecemos las coordenadas del selector.
							rselector_.x = 532;
							rselector_.y = 111;

							// Cambiamos la selección.
							seleccion = PRACTICAR;

							// Dibujamos.
							DibujarPrincipal();
							pantalla_ -> Actualizar();

							// Esperamos.
							SDL_Delay(Constantes::_MS_TECLA_);

							break;
						}

						case MATCHPLAY:
						{
							// Retorno de el menú de elección de jugadores.
							int retorno = ElegirJugadores(MATCHPLAY);
							
							// Hemos cerrado la ventana. Terminamos el juego.
							if(retorno == -1)
								return 0;

							// Establecemos las coordenadas del selector.
							rselector_.x = 532;
							rselector_.y = 111;

							// Cambiamos la selección.
							seleccion = PRACTICAR;

							// Dibujamos.
							DibujarPrincipal();
							pantalla_ -> Actualizar();

							// Esperamos.
							SDL_Delay(Constantes::_MS_TECLA_);

							break;
						}

						case STROKEPLAY:
						{
							// Retorno de el menú de elección de jugadores.
							int retorno = ElegirJugadores(STROKEPLAY);
							
							// Hemos cerrado la ventana. Terminamos el juego.
							if(retorno == -1)
								return 0;

							// Establecemos las coordenadas del selector.
							rselector_.x = 532;
							rselector_.y = 111;

							// Cambiamos la selección.
							seleccion = PRACTICAR;

							// Dibujamos.
							DibujarPrincipal();
							pantalla_ -> Actualizar();

							// Esperamos.
							SDL_Delay(Constantes::_MS_TECLA_);

							break;
						}

						case OPCIONES:
						{
							// Retorno de el menú de elección de jugadores.
							int retorno = this -> Opciones();
							
							// Hemos cerrado la ventana. Terminamos el juego.
							if(retorno == -1)
								return 0;

							// Establecemos las coordenadas del selector.
							rselector_.x = 532;
							rselector_.y = 111;

							// Cambiamos la selección.
							seleccion = PRACTICAR;

							// Dibujamos.
							DibujarPrincipal();
							pantalla_ -> Actualizar();

							// Esperamos.
							SDL_Delay(Constantes::_MS_TECLA_);

							break;
						}

						case ACERCADE:
						{
							// Cambiamos la selección.
							seleccion = ACEPTAR;
							
							// Establecemos las coordenadas del selector.	
							rselector_.x = 612;
							rselector_.y = 425;

							// Dibujamos.
							DibujarAcercaDe();
							pantalla_ -> Actualizar();
							
							// Esperamos.
							SDL_Delay(Constantes::_MS_TECLA_);

							break;
						}
						
						case ACEPTAR:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = 532;
							rselector_.y = 111;

							// Cambiamos la selección.
							seleccion = PRACTICAR;

							// Dibujamos.
							DibujarPrincipal();
							pantalla_ -> Actualizar();
							
							break;
						}

						case SALIR: return 0;

						default: break;
						
					}	
				}					
			}

			// Guardamos el tiempo para la cola de eventos.
			tb_while = SDL_GetTicks();

			// Si el tiempo transcurrido es menor al establecido, esperamos.
			if(tb_while - ta_while < Constantes::_MS_)
				SDL_Delay(Constantes::_MS_ - (tb_while-ta_while));
							
		} // while		

		// Guardamos el tiempo para el bucle.
		tb_for = SDL_GetTicks();

		// Si el tiempo transcurrido es menor al establecido, esperamos.
		if(tb_for - ta_for < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb_for - ta_for));

	} // for
}



void Menu::Acercade()
{

}


void Menu::JugadorAleatorio(int jugador, int modo)
{
	int nlineas = 0;

	// Determinamos el número de líneas.
	for(int x = 0; x < longitud_; ++x)
		if(fichero_[x] == '\n')
			++nlineas;

	// Creamos un vector en el que almacenaremos la longitud de cada línea.
	int *longitud_linea;
	longitud_linea = new int[nlineas];
	int linea = 0;

	int copia = -1;

	// Determinamos la longitude de cada línea.
	for(int x = 0; x < longitud_; ++x)
		if(fichero_[x] == '\n')
		{
			longitud_linea[linea] = x - 1 - copia;
			copia = x;
			++linea;
		}	
	
	// Generamos un número aleatorio que esté etnre el número de líneas total.
	int l = Utilidades::NumeroAleatorio(0, nlineas - 1);

	// Desplazamiento para obtener el nombre.
	int desplazamiento = 0;
	
	// Vamos sumando hasta llegar al número de línea.
	for(int x = 0; x < l; ++x)
		desplazamiento += longitud_linea[x];

	desplazamiento += 1 * l;
		
	// Cadena para el nombre.
	std::string nombre;	

	// Extraemos el nombre del vector.
	for(int x = 0; x < longitud_linea[l]; x++)
		nombre += fichero_[desplazamiento + x];
	
	// Convertimos el primer caracter a mayúsculas.
	nombre[0] = toupper(nombre[0]);

	// Convertimos los caracteres después de espacio a mayúsculas.
	for(unsigned int x=0; x < nombre.size(); ++x)
		if(nombre[x] == ' ' && x < nombre.size() -1)
			nombre[x + 1] = toupper(nombre[x + 1]);

	// Destruimos el vector de longitudes de líneas.	
	delete[] longitud_linea;
	
	// Eliminamos los datos previos
	EliminarNombre(jugador);
	EliminarTipo(jugador);
	EliminarColor(jugador);	

	// Generamos la imagen del nombre.
	sjugadores_[jugador] = Utilidades::CrearTexto(nombre.c_str(),
		Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

	// Establecemos el nombre del jugador.
	jugadores_[jugador] = nombre;
	
	// Establecemos un tipo aleatorio.
	Tipo(jugador, Utilidades::NumeroAleatorio(0, 3));
	
	// Establecemos un color aleatorio.
	EstablecerColor(jugador, Utilidades::NumeroAleatorio(0, ncolores_ - 1));

	// Dibujamos y mostramos por pantalla.
	DibujarElegirJugadores(modo);
	pantalla_ -> Actualizar();	
	
}


int Menu::ElegirJugadores(int modo)
{
	// Si la música está activada y no está sonando, la reproducimos.	
	if(musica_)
		if(!musica_fondo_.Reproduciendo())
			musica_fondo_.Reproducir(1);

	// Lista de opciones.
	enum elegir_jugadores {JUGADOR1, JUGADOR2, JUGADOR3, JUGADOR4, ACEPTAR,
		VOLVER, TIPO1, COLOR1, TIPO2, COLOR2, TIPO3, COLOR3, TIPO4, COLOR4};

	// Referencias de encuadre para los nombres.
	int xjugador1 = 98;
	int yjugador1 = 137;

	// Referencias de encuadre para los tipos.
	int xtipo1 = 368;
	int ytipo1 = 137;

	// Referencias de encuadre para los colores.
	int xcolor1 = 562;
	int ycolor1 = 137;
	
	// Referencias de encuadre para el botón aceptar.
	int xaceptar = 612;
	int yaceptar = 425;

	// Referencias de encuadre para el botón volver.
	int xvolver = 50;
	int yvolver = 425;

	// Separacion entre cajas.
	int separacion = 64;

	// Establecemos las coordenadas del selector.	
	rselector_.x = xjugador1;
	rselector_.y = yjugador1;

	// Establecemos la selección inicial.
	int seleccion = JUGADOR1;

	// Dibujamos.
	DibujarElegirJugadores(modo);
	pantalla_ -> Actualizar();

	// Variables de control de tiempo para el bucle.
	Uint32 ta_for, tb_for;

	// Varaibles de control de tiempo para el bucle de la cola de eventos.
	Uint32 ta_while, tb_while;

	// Evento a procesar.
	SDL_Event evento;

	// Tecla del evento.
	SDLKey &tecla = evento.key.keysym.sym;

	for(;;)
	{
		// Guardamos el tiempo para el control del bucle.
		ta_for = SDL_GetTicks();	

		// Si la música está activada y no está sonando, la reproducimos.
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Procesamos la cola de eventos.
		while(SDL_PollEvent(&evento))
		{
			// Guardamos el tiempo para el control del bucle de la cola de eventos.
			ta_while = SDL_GetTicks();	

			// Si cerramos la ventana terminamos el juego.
			if(evento.type == SDL_QUIT)
				return -1;

			// Se ha pulsado una tecla.
			if(evento.key.type == SDL_KEYDOWN)
			{
				// Pantalla completa.
				if(tecla == teclado_.Tecla(Teclado::PANTALLA_COMPLETA))
					pantalla_ -> PantallaCompleta();

				// Espacio.
				if(tecla == teclado_.Tecla(Teclado::ESPACIO))
				{
					// La selección es el nombre de un jugador.
					if(seleccion == JUGADOR1 || seleccion == JUGADOR2
					|| seleccion == JUGADOR3 || seleccion == JUGADOR4)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							cambiar_.Reproducir();

						// Generamos nombre aleatorio.
						JugadorAleatorio(seleccion, modo);

						// Esperamos.
						SDL_Delay(Constantes::_MS_TECLA_);
					}
				}

				// Borrar.
				if(tecla == teclado_.Tecla(Teclado::BORRAR))
				{
					// La selección es el nombre de un jugador.
					if(seleccion == JUGADOR1 || seleccion == JUGADOR2
					|| seleccion == JUGADOR3 || seleccion == JUGADOR4)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							cancelar_.Reproducir();

						// Eliminamos el nombre dle jugador, su tipo y el color.
						EliminarNombre(seleccion);
						EliminarTipo(seleccion);
						EliminarColor(seleccion);

						// Dibujamos.
						this -> DibujarElegirJugadores(modo);
						pantalla_ -> Actualizar();

						// Esperamos.
						SDL_Delay(Constantes::_MS_TECLA_);
					}				
				}

				// Opcion de abajo.
				if(tecla == teclado_.Tecla(Teclado::ABAJO))
				{
					// Guardamos la selección anterior.
					int previa = seleccion;

					switch(seleccion)
					{
						case JUGADOR1:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion;

							// Cambiamos la selección.
							seleccion = JUGADOR2;

							break;
						}

						case JUGADOR2:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion * 2;

							// Cambiamos la selección.
							seleccion = JUGADOR3;
							break;
						}

						case JUGADOR3:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion * 3;

							// Cambiamos la selección.
							seleccion = JUGADOR4;
							break;
						}

						case JUGADOR4:
						{
							// Elegimos el modo.
							if(modo == PRACTICAR || modo == STROKEPLAY)
							{
								// Hay al menos un jugador.
								if(Jugadores() > 0)
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xaceptar;
									rselector_.y = yaceptar;

									// Cambiamos la selección.
									seleccion = ACEPTAR;
								}
								else
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xvolver;
									rselector_.y = yvolver;

									// Cambiamos la selección.
									seleccion = VOLVER;							
								}
							}
							else
							{
								// Hay más de un jugador.
								if(Jugadores() > 1)
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xaceptar;
									rselector_.y = yaceptar;

									// Cambiamos la selección.
									seleccion = ACEPTAR;
								}
								else
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xvolver;
									rselector_.y = yvolver;

									// Cambiamos la selección.
									seleccion = VOLVER;							
								}							
							}
							break;
						}

						case TIPO1:
						{
							// El jugador existe.
							if(!jugadores_[1].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion;

								// Cambiamos la selección.
								seleccion = TIPO2;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion;

								// Cambiamos la selección.
								seleccion = JUGADOR2;							
							}
							break;
						}

						case TIPO2:
						{
							// El jugador existe.
							if(!jugadores_[2].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = TIPO3;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = JUGADOR3;							
							}
							break;
						}					

						case TIPO3:
						{
							// El jugador existe.
							if(!jugadores_[3].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion * 3;

								// Cambiamos la selección.
								seleccion = TIPO4;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion * 3;

								// Cambiamos la selección.
								seleccion = JUGADOR4;							
							}
							break;
						}	

						case TIPO4:
						{
							// Elegimos el modo.
							if(modo == PRACTICAR || modo == STROKEPLAY)
							{
								// Hay al menos un jugador.
								if(Jugadores() > 0)
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xaceptar;
									rselector_.y = yaceptar;

									// Cambiamos la selección.
									seleccion = ACEPTAR;
								}
								else
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xvolver;
									rselector_.y = yvolver;

									// Cambiamos la selección.
									seleccion = VOLVER;							
								}
							}
							else
							{
								// Hay más de un jugador.
								if(Jugadores() > 1)
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xaceptar;
									rselector_.y = yaceptar;

									// Cambiamos la selección.
									seleccion = ACEPTAR;
								}
								else
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xvolver;
									rselector_.y = yvolver;

									// Cambiamos la selección.
									seleccion = VOLVER;							
								}							
							}
							break;
						}

						case COLOR1:
						{
							// El jugador existe.
							if(!jugadores_[1].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xcolor1;
								rselector_.y = ycolor1 + separacion;

								// Cambiamos la selección.
								seleccion = COLOR2;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion;

								// Cambiamos la selección.
								seleccion = JUGADOR2;							
							}
							break;
						}

						case COLOR2:
						{
							// El jugador existe.
							if(!jugadores_[2].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xcolor1;
								rselector_.y = ycolor1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = COLOR3;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = JUGADOR3;							
							}
							break;
						}

						case COLOR3:
						{
							// El jugador existe.
							if(!jugadores_[3].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xcolor1;
								rselector_.y = ycolor1 + separacion * 3;

								// Cambiamos la selección.
								seleccion = COLOR4;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion * 3;

								// Cambiamos la selección.
								seleccion = JUGADOR4;							
							}
							break;
						}

						case COLOR4:
						{
							// Elegimos el modo.
							if(modo == PRACTICAR || modo == STROKEPLAY)
							{
								// Hay al menos un jugador.
								if(Jugadores() > 0)
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xaceptar;
									rselector_.y = yaceptar;

									// Cambiamos la selección.
									seleccion = ACEPTAR;
								}
								else
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xvolver;
									rselector_.y = yvolver;

									// Cambiamos la selección.
									seleccion = VOLVER;							
								}
							}
							else
							{
								// Hay más de un jugador.
								if(Jugadores() > 1)
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xaceptar;
									rselector_.y = yaceptar;

									// Cambiamos la selección.
									seleccion = ACEPTAR;
								}
								else
								{
									// Establecemos las coordenadas del selector.
									rselector_.x = xvolver;
									rselector_.y = yvolver;

									// Cambiamos la selección.
									seleccion = VOLVER;							
								}							
							}
							break;
						}

						default: break;

					} // switch

					// Si los efectos están activados, lo reproducimos.
					if(efectos_)					
						if(previa != ACEPTAR && previa != VOLVER)
							seleccionar_.Reproducir();

					// Dibujamos.
					DibujarElegirJugadores(modo);
					pantalla_ -> Actualizar();

				} // if


				// Opcion de arriba.
				if(tecla == teclado_.Tecla(Teclado::ARRIBA))
				{
					// Guardamos la selección anterior.
					int previa = seleccion;

					switch(seleccion)
					{
						case JUGADOR2:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1;

							// Cambiamos la selección.
							seleccion = JUGADOR1;
							break;
						}

						case JUGADOR3:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion;

							// Cambiamos la selección.
							seleccion = JUGADOR2;
							break;
						}

						case JUGADOR4:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion * 2;

							// Cambiamos la selección.
							seleccion = JUGADOR3;
							break;
						}

						case ACEPTAR:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion * 3;

							// Cambiamos la selección.
							seleccion = JUGADOR4;
							break;
						}

						case VOLVER:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion * 3;

							// Cambiamos la selección.
							seleccion = JUGADOR4;
							break;
						}

						case TIPO2:
						{
							// El jugador existe.
							if(!jugadores_[0].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1;

								// Cambiamos la selección.
								seleccion = TIPO1;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1;

								// Cambiamos la selección.
								seleccion = JUGADOR1;							
							}
							break;
						}

						case TIPO3:
						{
							// El jugador existe.
							if(!jugadores_[1].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion;

								// Cambiamos la selección.
								seleccion = TIPO2;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion;

								// Cambiamos la selección.
								seleccion = JUGADOR2;							
							}
							break;
						}

						case TIPO4:
						{
							// El jugador existe.
							if(!jugadores_[2].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = TIPO3;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = JUGADOR3;							
							}
							break;
						}

						case COLOR2:
						{
							// El jugador existe.
							if(!jugadores_[0].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xcolor1;
								rselector_.y = ycolor1;

								// Cambiamos la selección.
								seleccion = COLOR1;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1;

								// Cambiamos la selección.
								seleccion = JUGADOR1;							
							}
							break;
						}

						case COLOR3:
						{
							// El jugador existe.
							if(!jugadores_[1].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xcolor1;
								rselector_.y = ycolor1 + separacion;

								// Cambiamos la selección.
								seleccion = COLOR2;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion;

								// Cambiamos la selección.
								seleccion = JUGADOR2;							
							}
							break;
						}

						case COLOR4:
						{
							// El jugador existe.
							if(!jugadores_[2].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xcolor1;
								rselector_.y = ycolor1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = COLOR3;
							}
							else
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xjugador1;
								rselector_.y = yjugador1 + separacion * 2;

								// Cambiamos la selección.
								seleccion = JUGADOR3;							
							}
							break;
						}

						default: break;

					}

					// Si los efectos están activados, lo reproducimos.
					if(efectos_)
						if(previa != JUGADOR1 && previa != TIPO1 && previa != COLOR1)
							seleccionar_.Reproducir();

					// Dibujamos.
					DibujarElegirJugadores(modo);
					pantalla_ -> Actualizar();				
				}

				// Opción de la izquierda.
				if(tecla == teclado_.Tecla(Teclado::IZQUIERDA))
				{	
					// Guardamos la selección anterior.
					int previa = seleccion;

					switch(seleccion)
					{
						case ACEPTAR:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xvolver;
							rselector_.y = yvolver;

							// Cambiamos la selección.
							seleccion = VOLVER;
							break;
						}

						case TIPO1:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1;

							// Cambiamos la selección.
							seleccion = JUGADOR1;
							break;
						}

						case TIPO2:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion;

							// Cambiamos la selección.
							seleccion = JUGADOR2;
							break;
						}

						case TIPO3:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion * 2;

							// Cambiamos la selección.
							seleccion = JUGADOR3;
							break;
						}

						case TIPO4:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xjugador1;
							rselector_.y = yjugador1 + separacion * 3;

							// Cambiamos la selección.
							seleccion = JUGADOR4;
							break;
						}

						case COLOR1:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xtipo1;
							rselector_.y = ytipo1;

							// Cambiamos la selección.
							seleccion = TIPO1;
							break;
						}

						case COLOR2:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xtipo1;
							rselector_.y = ytipo1 + separacion;

							// Cambiamos la selección.
							seleccion = TIPO2;
							break;
						}

						case COLOR3:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xtipo1;
							rselector_.y = ytipo1 + separacion * 2;

							// Cambiamos la selección.
							seleccion = TIPO3;
							break;
						}

						case COLOR4:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xtipo1;
							rselector_.y = ytipo1 + separacion * 3;

							// Cambiamos la selección.
							seleccion = TIPO4;
							break;
						}

						default: break;

					}

					// Si los efectos están activados, lo reproducimos.
					if(efectos_)					
						if(previa != JUGADOR1 && previa != JUGADOR2 && previa != JUGADOR3
							&& previa != JUGADOR4 && previa != VOLVER)
							seleccionar_.Reproducir();

					// Dibujamos.
					DibujarElegirJugadores(modo);
					pantalla_ -> Actualizar();						
				}

				// Opción de la derecha.				
				if(tecla == teclado_.Tecla(Teclado::DERECHA))
				{
					// Opción de la izquierda.
					int previa = seleccion;

					switch(seleccion)
					{
						case VOLVER:
						{
							// Hay al menos un jugador.
							if(Jugadores() > 0 && modo != MATCHPLAY)
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xaceptar;
								rselector_.y = yaceptar;
								seleccion = ACEPTAR;
							}

							// Hay más de un jugador.
							else if(Jugadores() > 1)
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xaceptar;
								rselector_.y = yaceptar;
								seleccion = ACEPTAR;							
							}
							break;
						}

						case JUGADOR1:
						{
							// El jugador existe.
							if(!jugadores_[0].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1;		
								seleccion = TIPO1;
							}
							break;
						}

						case JUGADOR2:
						{
							// El jugador existe.
							if(!jugadores_[1].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion;		
								seleccion = TIPO2;					
							}
							break;
						}		

						case JUGADOR3:
						{
							// El jugador existe.
							if(!jugadores_[2].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion * 2;		
								seleccion = TIPO3;					
							}
							break;
						}

						case JUGADOR4:
						{
							// El jugador existe.
							if(!jugadores_[3].empty())
							{
								// Establecemos las coordenadas del selector.
								rselector_.x = xtipo1;
								rselector_.y = ytipo1 + separacion * 3;		
								seleccion = TIPO4;					
							}
							break;
						}

						case TIPO1:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xcolor1;
							rselector_.y = ycolor1;		
							seleccion = COLOR1;					
							break;
						}

						case TIPO2:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xcolor1;
							rselector_.y = ycolor1 + separacion;		
							seleccion = COLOR2;					
							break;
						}

						case TIPO3:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xcolor1;
							rselector_.y = ycolor1 + separacion * 2;		
							seleccion = COLOR3;					
							break;
						}

						case TIPO4:
						{
							// Establecemos las coordenadas del selector.
							rselector_.x = xcolor1;
							rselector_.y = ycolor1 + separacion * 3;		
							seleccion = COLOR4;					
							break;
						}

						default: break;
					}

					// Si los efectos están activados, lo reproducimos.
					if(efectos_)					
						if(previa != COLOR1 && previa != COLOR2 && previa != COLOR3
							&& previa != COLOR4 && previa != ACEPTAR
							&& seleccion != JUGADOR1 && seleccion != JUGADOR2
							&& seleccion != JUGADOR3 && seleccion != JUGADOR4
							&& seleccion != VOLVER)
							seleccionar_.Reproducir();

					// Dibujamos.
					DibujarElegirJugadores(modo);
					pantalla_ -> Actualizar();
				}

				// Aceptamos la opción.
				if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
				{

					if(seleccion == VOLVER)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							cancelar_.Reproducir();

						// Eliminamos los datos.
						EliminarDatosElegirJugador();

						// Volvemos.
						return 0;
					}

					if(seleccion == JUGADOR1 || seleccion == JUGADOR2
						|| seleccion == JUGADOR3 || seleccion == JUGADOR4)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							aceptar_.Reproducir();

						// Capturamos texto desde el teclado.
						// Si se ha cerrado la ventana mientras se capturaba texto,
						// terminamos el juego.
						if(CapturarTexto(seleccion, modo) == 1)
							return -1;

						// Esperamos.
						SDL_Delay(Constantes::_MS_TECLA_);
					}

					if(seleccion == TIPO1 || seleccion == TIPO2
						|| seleccion == TIPO3 || seleccion == TIPO4)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							cambiar_.Reproducir();

						// Determinamos el jugador.
						int jugador = 0;

						switch(seleccion)
						{
							case TIPO1: jugador = JUGADOR1; break;
							case TIPO2: jugador = JUGADOR2; break;
							case TIPO3: jugador = JUGADOR3; break;
							case TIPO4: jugador = JUGADOR4; break;
						}

						// Cambiaos el tipo del jugador.
						SiguienteTipo(jugador);

						// Dibujamos.
						DibujarElegirJugadores(modo);
						pantalla_ -> Actualizar();

						// Esperamos.
						SDL_Delay(Constantes::_MS_TECLA_);
					}

					if(seleccion == COLOR1 || seleccion == COLOR2
						|| seleccion == COLOR3 || seleccion == COLOR4)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							cambiar_.Reproducir();

						// Determinamos el jugador.
						int jugador = 0;
						switch(seleccion)
						{
							case COLOR1: jugador = JUGADOR1; break;
							case COLOR2: jugador = JUGADOR2; break;
							case COLOR3: jugador = JUGADOR3; break;
							case COLOR4: jugador = JUGADOR4; break;
						}

						// Cambiaos el el color.
						SiguienteColor(jugador);

						// Dibujamos.
						DibujarElegirJugadores(modo);
						pantalla_ -> Actualizar();

						// Esperamos.
						SDL_Delay(Constantes::_MS_TECLA_);
					}

					if(seleccion == ACEPTAR)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							aceptar_.Reproducir();

						// Borramos los datos de los jugadores.
						datos_jugadores_.clear();

						Datos::Jugador tmp;

						// Introducimos los datos nuevos.
						for(int x = 0; x < njugadores_; x++)
						{
							if(!jugadores_[x].empty())
							{
								tmp.nombre_ = jugadores_[x];
								tmp.color_ = colores_[x];
								tmp.tipo_ = tipos_[x];
								tmp.equipo_ = -1;
								datos_jugadores_.push_back(tmp);
							}
						}

						// Retorno de la llamada al siguiente menú.
						int retorno;
						
						// En caso de que el modo de juego sea Matchplay y haya más
						// de 2 jugadores, elegimos las parejas.
						if(modo == MATCHPLAY && datos_jugadores_.size() > 2)
						{
							// Al elegir pareja determinaremos también el tipo de Matchplay
							// que queremos jugar (bolas compartidas o independientes).
							retorno = ElegirPareja();
						}
						else
						{
							// No es necesario elegir pareja, ya que el número de jugadores
							// es menor que 2, por lo tanto, elegimos el campo de juego.
							// Establecemos el tipo de Matchplay a bolas independientes.
							if(modo == MATCHPLAY)
							{
								datos_jugadores_[0].equipo_ = 0;
								datos_jugadores_[1].equipo_ = 1;
								tipo_matchplay_ = Matchplay::BOLAS_INDEPENDIENTES;
							}
							retorno = ElegirCampo(modo);
						}
						
						// Hemos vuelto de ElegirCampo a ElegirJugadores.
						if(retorno == 1)
						{					
							seleccion = JUGADOR1;
							rselector_.x = xjugador1;
							rselector_.y = yjugador1;
							DibujarElegirJugadores(modo);
							pantalla_ -> Actualizar();
						}
						// Hemos vuelto desde el menú de pausa, la opción salir.
						else if(retorno == 0)
							return 0;
						// Hemos pulsado la x de cerrar ventana.
						else if(retorno == -1)
							return -1;					
					}

				} // Teclado::ACEPTAR
			} // KEY_DOWN

			// Guardamos el tiempo para la cola de eventos.
			tb_while = SDL_GetTicks();

			// Si el tiempo transcurrido es menor que el establecido, esperamos.
			if(tb_while - ta_while < Constantes::_MS_)
				SDL_Delay(Constantes::_MS_ - (tb_while - ta_while));
				
		} // while

		// Guardamos el tiempo para el bucle.
		tb_for = SDL_GetTicks();

		// Si el tiempo transcurrido es menor que el establecido, esperamos.
		if(tb_for - ta_for < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb_for - ta_for));
	
	} // for

	return 0;
}

int Menu::Jugadores() const
{
	int n = 0;
	
	// Recorremos los nombres de los jugadores.
	for(std::vector<std::string>::const_iterator i = jugadores_.begin();
		i != jugadores_.end(); ++i)
		if(*i != "")
			++n;

	// Devolvemos el número de jugadores.
	return n;
}

int Menu::IniciarPartida(int modo)
{
	// Eliminamos todos los datos.
	EliminarDatosElegirJugador();
	EliminarDatosElegirCampo();
	EliminarDatosElegirPareja();

	// Paramos la música.
	Mix_HaltMusic();
	
	// Creamos la partida en función del modo.
	if(modo == PRACTICAR)
		partida_ =	new Practicar(datos_jugadores_, datos_campos_.back(),
			this, pantalla_);
	else if(modo == MATCHPLAY)
		partida_ =	new Matchplay(datos_jugadores_, datos_campos_,
			tipo_matchplay_, this, pantalla_);
	else if(modo == STROKEPLAY)
		partida_ =	new Strokeplay(datos_jugadores_, datos_campos_,
			this, pantalla_);

	// Guardamos el retorno de la partida.
	int retorno_partida = partida_ -> Iniciar();
	
	// Destruimos la partida.
	delete partida_;
	partida_ = 0;

	// Devolvemos el retorno de la partida.
	return retorno_partida;
}



int Menu::CapturarTexto(int jugador, int modo)
{
	// Activamos el teclado UNICODE.
	SDL_EnableUNICODE(SDL_ENABLE);

	// Texto que vamos a capturar.
	std::string texto_;
	
	// Evento para las pulsaciones de tecla.
	SDL_Event evento;
	
	// Tecla pulsada.
	SDLKey &tecla = evento.key.keysym.sym;
	
	// Correspondencia de la tecla y su caracter.
	char caracter_introducido;
	
	// Marcadores de tiempo para el control de velocidad.
	Uint32 ta, tb;
	
	// Número de caracteres que tiene el nombre del jugador.
	int numero_caracteres;
	
	// Número de caracteres que se permiten como máximo.
	int caracteres_maximos = 14;
	
	// Elegimos el jugador.
	numero_caracteres = jugadores_[jugador].size();
	texto_ = jugadores_[jugador];
	
	// Variables de control para los modos de edición.
	bool insertar = false;
	bool borrar = false;
	bool editar = false;
	bool terminar = false;
	

	// Insertamos el caracter '_'.
	editar = true;
	caracter_introducido = '_';
	
	while(1)
	{
		// Guardamos el tiempo para el control del bucle.
		ta = SDL_GetTicks();

		// Si la música está activada y no está sonando, la reproducimos.
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Extraemos el evento.
		SDL_PollEvent(&evento);

		if(evento.type == SDL_QUIT)
			return 1;

		// Se ha pulsado una tecla.
		if(evento.type == SDL_KEYDOWN)
		{
			// Aceptamos.
			if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
			{
				// Variable para controlar si la cadena contiene sólo espacios.
				bool solo_espacios = false;
				std::string tmp;

				// Introducimos todos los caracteres que no sean espacios.
				for(unsigned int x = 0; x < texto_.size(); ++x)
					if(texto_[x] != ' ')
						tmp.push_back(texto_[x]);

				// Buscamos si hay algún caracter que sea diferente al espacio.
				size_t n = tmp.find_first_not_of("_");

				// Si no hemos encontrado un caracter diferente, sólo hay espacios.
				if(n == std::string::npos && texto_.size() > 1)
					solo_espacios = true;

				// Si el texto no esta vacío y tampoco hay unicamente espacios,
				// terminamos.
				if(!texto_.empty() && !solo_espacios)
				{
					texto_.erase(texto_.size() - 1);
					borrar = true;
					terminar = true;
				}
			}
			// Hemos pulsado borrar.
			else if(tecla == teclado_.Tecla(Teclado::BORRAR))
			{
				// Borramos el último caracter introducido.
				if(texto_.size() > 1)
				{
					texto_.erase(texto_.size() - 2);
					texto_ += '_';
					borrar = true;
				}
			}
			// Cancelamos la captura de texto y borramos el nombre.
			else if(tecla == teclado_.Tecla(Teclado::ESCAPE))
			{
				texto_.clear();
				borrar = true;
				terminar = true;
			}
			// Controlamos el número de caracteres introducidos.
			else if(numero_caracteres < caracteres_maximos)
			{	
				caracter_introducido = teclado_.ObtenerUnicode(&(evento.key));
				
				if(caracter_introducido != 0)
				{
					if(efectos_)
						cambiar_.Reproducir();
					
					insertar = true;
				}
			}
		} // SDL_KEYDOWN

		// Procesamos la acción.
		if(insertar || borrar || editar)
		{			
			if(!borrar)
			{
				// Si el texto tiene al menos un caracter.
				if(texto_.size() >= 1 && !editar)
				{
					// Eliminamos '_'.
					texto_.erase(texto_.size() - 1);

					// Insertamos el caracter.
					texto_ += caracter_introducido;

					// Insertamos de nuevo '_'.
					texto_ += '_';
				}
				else
					
					texto_ += caracter_introducido;
			}

			// Si la imagen del nombre del jugador ya está creada, la borramos.
			if(sjugadores_[jugador] != 0)
			{
				SDL_FreeSurface(sjugadores_[jugador]);
				sjugadores_[jugador] = 0;
			}

			// Si el texto no esta vacío, generamos la nueva imagen del nombre
			// del jugador.
			if(!texto_.empty())
				sjugadores_[jugador] = Utilidades::CrearTexto(texto_.c_str(),
					Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
			
			// Establecemos el nombre del jugador	
			jugadores_[jugador] = texto_;
			
			// Actualizamos el número de caracteres que tiene el nombre
			numero_caracteres = jugadores_[jugador].size();

			// Dibujamos.
			DibujarElegirJugadores(modo);
			pantalla_ -> Actualizar();

			// Si hemos insertado, esperamos.
			if(insertar)
				SDL_Delay(Constantes::_MS_TECLA_);

			// Establecemos el tipo del evento a 0 para evitar procesarlo otra vez.		
			evento.type = 0;

			// Reiniciamos las variables de edición.
			insertar = false;
			borrar = false;
			editar = false;

			// Terminamos.
			if(terminar)
			{
				// Desactivamos el teclado UNICODE.
				SDL_EnableUNICODE(SDL_DISABLE);

				// Si hemos creado el nombre del jugador, le asignamos el tipo y
				// el color.
				if(jugadores_[jugador].size() != 0 && tipos_[jugador] == -1)
				{						
					Tipo(jugador, Jugador::HUMANO);
					EstablecerColor(jugador,
						Utilidades::NumeroAleatorio(0, ncolores_ - 1));
				}
	
				// Si al final no hay nombre, borramos todos los datos.
				if(jugadores_[jugador].empty())
				{
					// Si los efectos están activados, lo reproducimos.
					if(efectos_)
						cancelar_.Reproducir();

					// Eliminamos los datos.
					EliminarTipo(jugador);
					EliminarColor(jugador);
				}

				// Dibujamos.
				DibujarElegirJugadores(modo);
				pantalla_ -> Actualizar();
				
				break;
			}
			
		} // if

		// Guardamos el tiempo.
		tb = SDL_GetTicks();

		// Si el tiempo transcurrido es menor que el establecido, esperamos.
		if(tb - ta < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb-ta));
	
	} // while
	
	return 0;
}

void Menu::Tipo(int jugador, int tipo)
{
	// Si la imagen del tipo ya existe, la eliminamos.
	if(stipos_[jugador] != 0)
	{
		SDL_FreeSurface(stipos_[jugador]);
		stipos_[jugador] = 0;	
	}

	// Creamos la imagen del texto para el tipo HUMANO y asignamos el tipo.
	if(tipo == Jugador::HUMANO)
	{
		stipos_[jugador] = Utilidades::CrearTexto("Humano",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::HUMANO;		
	}

	// Creamos la imagen del texto para el tipo IA baja y asignamos el tipo.
	if(tipo == Jugador::IA_BAJA)
	{
		stipos_[jugador] = Utilidades::CrearTexto("IA baja",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::IA_BAJA;		
	}

	// Creamos la imagen del texto para el tipo IA media y asignamos el tipo.
	if(tipo == Jugador::IA_MEDIA)
	{
		stipos_[jugador] = Utilidades::CrearTexto("IA media",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::IA_MEDIA;		
	}

	// Creamos la imagen del texto para el tipo IA alta y asignamos el tipo.
	if(tipo == Jugador::IA_ALTA)
	{
		stipos_[jugador] = Utilidades::CrearTexto("IA alta",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::IA_ALTA;		
	}
}

void Menu::SiguienteTipo(int jugador)
{
	// Si hemos llegado al último tipo, volvemos al del principio.
	if(tipos_[jugador] == ntipos_ - 1)
		tipos_[jugador] = 0;

	// En caso contrario, aumentamos el tipo.
	else
		tipos_[jugador] =  ++ tipos_[jugador];

	// Si la imagen del tipo ya existe, la eliminamos.
	if(stipos_[jugador] != 0)
	{
		SDL_FreeSurface(stipos_[jugador]);
		stipos_[jugador] = 0;	
	}

	// Creamos la imagen del texto para el tipo HUMANO y asignamos el tipo.
	if(tipos_[jugador] == Jugador::HUMANO)
	{
		stipos_[jugador] = Utilidades::CrearTexto("Humano",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::HUMANO;		
	}

	// Creamos la imagen del texto para el tipo IA baja y asignamos el tipo.
	if(tipos_[jugador] == Jugador::IA_BAJA)
	{
		stipos_[jugador] = Utilidades::CrearTexto("IA baja",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::IA_BAJA;		
	}

	// Creamos la imagen del texto para el tipo IA media y asignamos el tipo.
	if(tipos_[jugador] == Jugador::IA_MEDIA)
	{
		stipos_[jugador] = Utilidades::CrearTexto("IA media",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::IA_MEDIA;		
	}

	// Creamos la imagen del texto para el tipo IA alta y asignamos el tipo.
	if(tipos_[jugador] == Jugador::IA_ALTA)
	{
		stipos_[jugador] = Utilidades::CrearTexto("IA alta",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));
		tipos_[jugador] = Jugador::IA_ALTA;		
	}

}

void Menu::EliminarNombre(int jugador)
{
	// Eliminamos la imagen del texto del nombre del jugador.
	if(sjugadores_[jugador] != 0)
	{
		SDL_FreeSurface(sjugadores_[jugador]);
		sjugadores_[jugador] = 0;	
	}
	
	// Eliminamos la cadena del nombre.
	jugadores_[jugador].clear();
}

void Menu::EliminarTipo(int jugador)
{
	// Eliminamos la imagen del texto del tipo de jugador.
	if(stipos_[jugador] != 0)
	{
		SDL_FreeSurface(stipos_[jugador]);
		stipos_[jugador] = 0;	
	}

	// Establecemos el tipo a un valor no válido.
	tipos_[jugador] = -1;
}

void Menu::EliminarColor(int jugador)
{
	// Establecemos el color a un valor no válido.
	colores_[jugador] = -1;
}

void Menu::SiguienteColor(int jugador)
{
	// Guardamos el color actual.
	int color = colores_[jugador];

	// rojo marron amarillo rosa azul cyan
	// Si hemos llegado al último color, volvemos al principio.
	if(color == ncolores_ -1)
		color = 0;
	else
		++ color;

	// Establecemos el color.
	colores_[jugador] = color;

	// Seleccionamos el color correspondiente en la rejilla.
	rejilla_colores_ -> SeleccionarCuadro(color);	
}


void Menu::EstablecerColor(int jugador, int color)
{
	// Establecemos el color.
	colores_[jugador] = color;

	// Seleccionamos el color correspondiente en la rejilla.
	rejilla_colores_ -> SeleccionarCuadro(color);
}

void Menu::EliminarDatosElegirJugador()
{

	// Eliminamos todas las imagenes de los nombres de los jugadores.
	for(int x = 0; x < njugadores_; ++x)
	{
		if(sjugadores_[x] != 0)
			SDL_FreeSurface(sjugadores_[x]);

		sjugadores_[x] = 0;
		jugadores_[x] = "";
	}

	// Eliminamos todas las imagenes de los tipos de los jugadores.
	for(int x = 0; x < ntipos_; ++x)
	{
		if(stipos_[x] != 0)
			SDL_FreeSurface(stipos_[x]);

		stipos_[x] = 0;
		tipos_[x] = -1;
	}

	// Establecemos todos los colores de los jugadores a un valor no válido.
	for(int x = 0; x < ncolores_; ++x)
		colores_[x] = -1;	
}

void Menu::EliminarDatosElegirCampo()
{
	// Destruimos las imágenes del menú.
	SDL_FreeSurface(imagen_hoyo_);
	SDL_FreeSurface(nombre_campo_);
	SDL_FreeSurface(numero_hoyo_);

	// Establecemos los punteros a un valor nulo.
	imagen_hoyo_ = 0;
	nombre_campo_ = 0;
	numero_hoyo_ = 0;
}



int Menu::ElegirCampo(int modo)
{
	// Si la música está activada y no está sonando, la reproducimos.
	if(musica_)
		if(!musica_fondo_.Reproduciendo())
			musica_fondo_.Reproducir(1);

	// Lista de opciones.
	enum elegir_campo {CAMPO, HOYO, JUGAR, VOLVER};

	// Documento xml.
	TiXmlDocument campos_xml;

	// Cargamos el fichero de campos.
	if(!campos_xml.LoadFile( "./cfg/campos.xml" ))
	{
		std::cerr << "Menu::ElegirCampo() Error: No se puede abrir campos.xml."
			<< std::endl;
		return EXIT_FAILURE;
	}
	
	// Establecemos la raiz del documento.
	TiXmlElement *raiz = campos_xml.RootElement();

	// Establecemos el elemento campos como el hijo de la raiz.
	TiXmlElement* campos = raiz -> FirstChildElement();

	// Establecemos el elemento hoyos como el hijo de campos.
	TiXmlElement* hoyos = campos -> FirstChildElement() -> FirstChildElement();

	// Cadena de ruta del campo.
	std::string ruta;
	
	// Generamos la ruta leyendo los atributos.
	ruta.append(Constantes::_IMG_CAMPO_);
	ruta.append(campos -> Attribute("ruta"));
	ruta.append("/");
	ruta.append(hoyos -> Attribute("numero"));
	ruta.append("_menu.png");

	// Cargamos la imagen del hoyo.	
	imagen_hoyo_ = Utilidades::CargarImagen(ruta);

	// Leemos el nombre del campo.
	std::string nombre_campo = campos -> Attribute("nombre");

	// Leemos el número del hoyo.
	std::string numero_hoyo = "Hoyo ";
	numero_hoyo.append(hoyos -> Attribute("numero"));
	
	// Creamos la imagen del nombre del campo.
	nombre_campo_ = Utilidades::CrearTexto(nombre_campo.c_str(),
		Constantes::_FUENTE_, 28, Utilidades::Color(Utilidades::BLANCO));

	// Creamos la imagen del número del hoyo.
	numero_hoyo_ = Utilidades::CrearTexto(numero_hoyo.c_str(),
		Constantes::_FUENTE_, 28, Utilidades::Color(Utilidades::BLANCO));

	// Guardamos el ancho y el alto de la imagen.
	rnombre_campo_.w = nombre_campo_ -> w;
	rnombre_campo_.h = nombre_campo_ -> h;

	// Establecemos las coordenadas.
	rnombre_campo_.x = (pantalla_ -> Ancho() / 2) - (rnombre_campo_.w / 2);
	rnombre_campo_.y = 310;	

	// Guardamos el ancho y el alto de la imagen.
	rnumero_hoyo_.w = numero_hoyo_ -> w;
	rnumero_hoyo_.h = numero_hoyo_ -> h;

	// Establecemos las coordenadas.
	rnumero_hoyo_.x = (pantalla_ -> Ancho() / 2) - (rnumero_hoyo_.w / 2);
	rnumero_hoyo_.y = 350;

	// Establecemos las coordenadas del selector.
	rselector_.x = rnombre_campo_.x - rselector_.w - 10;
	rselector_.y = (rnombre_campo_.y + rnombre_campo_.h / 2)
		- (rselector_.h / 2);

	// Establecemos la selección inicial.
	int seleccion = CAMPO;
	
	// Dibujamos.
	DibujarElegirCampo(modo);
	pantalla_ -> Actualizar();

	// Variables de control de tiempo para el bucle.
	Uint32 ta_for, tb_for;

	// Varaibles de control de tiempo para el bucle de la cola de eventos.
	Uint32 ta_while, tb_while;

	// Evento a procesar.	
	SDL_Event evento;

	// Tecla del evento.
	SDLKey &tecla = evento.key.keysym.sym;

	for(;;)
	{
		// Guardamos el tiempo para el control del bucle.
		ta_for = SDL_GetTicks();

		// Si la música está activada y no está sonando, la reproducimos.	
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Procesamos la cola de eventos.
		while(SDL_PollEvent(&evento))
		{
			// Guardamos el tiempo para el control del bucle de la cola de eventos.
			ta_while = SDL_GetTicks();

			// Si cerramos la ventana terminamos el juego.
			if(evento.type == SDL_QUIT)
				return -1;

			// Se ha pulsado una tecla.
			if(evento.key.type == SDL_KEYDOWN)
			{
				// Pantalla completa.
				if(tecla == teclado_.Tecla(Teclado::PANTALLA_COMPLETA))
					pantalla_ -> PantallaCompleta();

				// Opción de la izquierda.
				if(tecla == teclado_.Tecla(Teclado::IZQUIERDA))
				{
					if(seleccion == JUGAR)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Cambiamos la selección.
						seleccion = VOLVER;

						// Establecemos las coordenadas.
						rselector_.x = 50;
						rselector_.y = 425;

						// Dibujamos.
						DibujarElegirCampo(modo);
						pantalla_ -> Actualizar();					
					}
				
				}

				// Opción de la izquierda.
				if(tecla == teclado_.Tecla(Teclado::DERECHA))
				{
					if(seleccion == VOLVER)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Cambiamos la selección.
						seleccion = JUGAR;

						// Establecemos las coordenadas.
						rselector_.x = 612;
						rselector_.y = 425;

						// Dibujamos.
						DibujarElegirCampo(modo);
						pantalla_ -> Actualizar();					
					}
				
				}

				// Opción de abajo.
				if(tecla == teclado_.Tecla(Teclado::ABAJO))
				{
					switch(seleccion)
					{
						case CAMPO:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							if(modo == PRACTICAR)
							{
								// Cambiamos la selección.
								seleccion = HOYO;

								// Establecemos las coordenadas.
								rselector_.x = rnumero_hoyo_.x - rselector_.w - 10;
								rselector_.y = (rnumero_hoyo_.y + rnumero_hoyo_.h / 2)
									- (rselector_.h / 2);
							}
							else
							{
								// Cambiamos la selección.
								seleccion = JUGAR;

								// Establecemos las coordenadas.
								rselector_.x = 612;
								rselector_.y = 425;
							}

							// Dibujamos.
							DibujarElegirCampo(modo);
							pantalla_ -> Actualizar();

							break;
						}
						case HOYO:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();	

							// Cambiamos la selección.
							seleccion = JUGAR;

							// Establecemos las coordenadas.
							rselector_.x = 612;
							rselector_.y = 425;

							// Dibujamos.
							DibujarElegirCampo(modo);
							pantalla_ -> Actualizar();

							break;
						}
					}
					
				}

				// Opción de arriba.
				if(tecla == teclado_.Tecla(Teclado::ARRIBA))
				{
					switch(seleccion)
					{
						case HOYO:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Establecemos las coordenadas.
							rselector_.x = rnombre_campo_.x - rselector_.w - 10;
							rselector_.y = (rnombre_campo_.y + rnombre_campo_.h / 2)
								- (rselector_.h / 2);

							// Cambiamos la selección.
							seleccion = CAMPO;

							// Dibujamos.
							DibujarElegirCampo(modo);
							pantalla_ -> Actualizar();

							break;
						}
						case JUGAR:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();
							
							if(modo == PRACTICAR)
							{
								// Cambiamos la selección.
								seleccion = HOYO;

								// Establecemos las coordenadas.
								rselector_.x = rnumero_hoyo_.x - rselector_.w - 10;
								rselector_.y = (rnumero_hoyo_.y + rnumero_hoyo_.h / 2)
									- (rselector_.h / 2);

							}
							else
							{
								// Cambiamos la selección.
								seleccion = CAMPO;

								// Establecemos las coordenadas.
								rselector_.x = rnombre_campo_.x - rselector_.w - 10;
								rselector_.y = (rnombre_campo_.y + rnombre_campo_.h / 2)
									- (rselector_.h / 2);					
							}

							// Dibujamos.
							DibujarElegirCampo(modo);
							pantalla_ -> Actualizar();

							break;
						}
						case VOLVER:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							if(modo == PRACTICAR)
							{
								// Cambiamos la selección.
								seleccion = HOYO;

								// Establecemos las coordenadas.
								rselector_.x = rnumero_hoyo_.x - rselector_.w - 10;
								rselector_.y = (rnumero_hoyo_.y + rnumero_hoyo_.h / 2)
									- (rselector_.h / 2);
							}
							else
							{
								// Cambiamos la selección.
								seleccion = CAMPO;

								// Establecemos las coordenadas.
								rselector_.x = rnombre_campo_.x - rselector_.w - 10;
								rselector_.y = (rnombre_campo_.y + rnombre_campo_.h / 2)
									- (rselector_.h / 2);					
							}							

							// Dibujamos.
							DibujarElegirCampo(modo);
							pantalla_ -> Actualizar();

							break;						
						}
					}
				}

				// Aceptamos la opción.
				if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
				{

					if(seleccion == JUGAR)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							aceptar_.Reproducir();

						// Datos del hoyo.
						Datos::Campo tmp;
						
						if(modo == PRACTICAR)
						{
							// Establecemos los datos del único hoyo.

							tmp.nombre_ = nombre_campo;	
							tmp.ruta_ = campos -> Attribute("ruta");
							tmp.colores_ = campos -> Attribute("colores");
							tmp.animaciones_ = campos -> Attribute("animaciones");
							tmp.hoyo_ = hoyos -> Attribute("numero");
							tmp.par_ = hoyos -> Attribute("par");
							tmp.posicion_salida_.x =
								atoi(hoyos -> Attribute("x_bola"));
							tmp.posicion_salida_.y =
								atoi(hoyos -> Attribute("y_bola"));
							tmp.posicion_hoyo_.x =
								atoi(hoyos -> Attribute("x_hoyo"));
							tmp.posicion_hoyo_.y =
								atoi(hoyos -> Attribute("y_hoyo"));
						
							datos_campos_.clear();
							datos_campos_.push_back(tmp);
						}
						else
						{
							// Eliminamos los datos del campo.
							datos_campos_.clear();

							// Vamos introduciendo los datos mientras hayan hoyos.
							do
							{
								// Establecemos los datos del campo leyendo el valor de los
								// atributos.
								tmp.nombre_ = nombre_campo;	
								tmp.ruta_ = campos -> Attribute("ruta");
								tmp.colores_ = campos -> Attribute("colores");
								tmp.animaciones_ = campos -> Attribute("animaciones");
								tmp.hoyo_ = hoyos -> Attribute("numero");
								tmp.par_ = hoyos -> Attribute("par");
								tmp.posicion_salida_.x =
									atoi(hoyos -> Attribute("x_bola"));
								tmp.posicion_salida_.y =
									atoi(hoyos -> Attribute("y_bola"));
								tmp.posicion_hoyo_.x =
									atoi(hoyos -> Attribute("x_hoyo"));
								tmp.posicion_hoyo_.y =
									atoi(hoyos -> Attribute("y_hoyo"));
						
								datos_campos_.push_back(tmp);

								hoyos = hoyos -> NextSiblingElement();
							}
							while(hoyos);
						}
						
						// Elegimos el modo e iniciamos la partida.
						switch(modo)
						{
							case PRACTICAR: return IniciarPartida(PRACTICAR);
							case MATCHPLAY: return IniciarPartida(MATCHPLAY);
							case STROKEPLAY: return IniciarPartida(STROKEPLAY);
							default: break;
						}
					}

					
					if(seleccion == CAMPO)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							cambiar_.Reproducir();

						// Seleccionamos el siguiente campo.
						campos = campos -> NextSiblingElement();
						
						// Si no hay mas campos volvemos al principio.
						if(!campos)
							campos = raiz -> FirstChildElement();
						
						// Leemos el nombre del campo.
						nombre_campo = campos -> Attribute("nombre");
						
						// Reenderizamos el nuevo nombre.
						SDL_FreeSurface(nombre_campo_);						
						nombre_campo_ = Utilidades::CrearTexto(nombre_campo.c_str(),
							Constantes::_FUENTE_, 28, Utilidades::Color(Utilidades::BLANCO));

						// Cogemos el primer hoyo del campo.
						hoyos = campos -> FirstChildElement() -> FirstChildElement();
						
						// Generamos el texto del número de hoyo.
						numero_hoyo = "Hoyo ";
						numero_hoyo.append(hoyos -> Attribute("numero"));

						// Reenderizamos el texto del número de hoyo.
						SDL_FreeSurface(numero_hoyo_);
						numero_hoyo_ = Utilidades::CrearTexto(numero_hoyo.c_str(),
							Constantes::_FUENTE_, 28, Utilidades::Color(Utilidades::BLANCO));

						// Cargamos la imagen del hoyo.
						ruta="";
						ruta.append(Constantes::_IMG_CAMPO_);
						ruta.append(campos -> Attribute("ruta"));
						ruta.append("/");
						ruta.append(hoyos -> Attribute("numero"));
						ruta.append("_menu.png");
						SDL_FreeSurface(imagen_hoyo_);
						imagen_hoyo_ = Utilidades::CargarImagen(ruta);
						
						// Establecemos la posición del nombre del campo.
						rnombre_campo_.w = nombre_campo_ -> w;
						rnombre_campo_.h = nombre_campo_ -> h;
						rnombre_campo_.x = (pantalla_ -> Ancho() / 2)
							- (rnombre_campo_.w / 2);
						rnombre_campo_.y = 310;								

						// Establecemos la posición del número de hoyo.
						rnumero_hoyo_.w = numero_hoyo_ -> w;
						rnumero_hoyo_.h = numero_hoyo_ -> h;
						rnumero_hoyo_.x = (pantalla_ -> Ancho() / 2)
							- (rnumero_hoyo_.w / 2);
						rnumero_hoyo_.y = 350;

						// Establecemos la posición del selector.
						rselector_.x = rnombre_campo_.x - rselector_.w - 10;
						rselector_.y = (rnombre_campo_.y + rnombre_campo_.h / 2)
							- (rselector_.h / 2);

						DibujarElegirCampo(modo);
						pantalla_ -> Actualizar();						
						SDL_Delay(Constantes::_MS_TECLA_);
					}
					else if(seleccion == HOYO)
					{
						if(efectos_)
							cambiar_.Reproducir();

						// Cogemos el siguiente hoyo.
						hoyos = hoyos -> NextSiblingElement();				

						// Si no hay más hoyos volvemos al primero.
						if(!hoyos)
							hoyos = campos -> FirstChildElement() -> FirstChildElement();

						// Generamos el texto del número de hoyo.
						numero_hoyo = "Hoyo ";
						numero_hoyo.append(hoyos -> Attribute("numero"));

						// Reenderizamos el texto del número de hoyo.
						SDL_FreeSurface(numero_hoyo_);
						numero_hoyo_ = Utilidades::CrearTexto(numero_hoyo.c_str(),
							Constantes::_FUENTE_, 28, Utilidades::Color(Utilidades::BLANCO));

						// Cargamos la imagen del hoyo.
						ruta="";
						ruta.append(Constantes::_IMG_CAMPO_);
						ruta.append(campos -> Attribute("ruta"));
						ruta.append("/");
						ruta.append(hoyos -> Attribute("numero"));
						ruta.append("_menu.png");
						SDL_FreeSurface(imagen_hoyo_);
						imagen_hoyo_ = Utilidades::CargarImagen(ruta);

						// Establecemos la posición del número de hoyo.
						rnumero_hoyo_.w = numero_hoyo_ -> w;
						rnumero_hoyo_.h = numero_hoyo_ -> h;
						rnumero_hoyo_.x = (pantalla_ -> Ancho() / 2)
							- (rnumero_hoyo_.w / 2);
						rnumero_hoyo_.y = 350;

						// Establecemos la posición del selector.
						rselector_.x = rnumero_hoyo_.x - rselector_.w - 10;
						rselector_.y = (rnumero_hoyo_.y + rnumero_hoyo_.h / 2)
							- (rselector_.h / 2);

						// Dibujamos y actualizamos.
						DibujarElegirCampo(modo);
						pantalla_ -> Actualizar();

						// Esperamos.
						SDL_Delay(Constantes::_MS_TECLA_);
					}
					else if(seleccion == VOLVER)
					{
						if(efectos_)
							cancelar_.Reproducir();
						EliminarDatosElegirCampo();
						return 1;
					}
				}					
			}

			// Guardamos el tiempo para la cola de eventos.
			tb_while = SDL_GetTicks();

			// Si el tiempo transcurrido es menor al establecido, esperamos.
			if(tb_while - ta_while < Constantes::_MS_)
				SDL_Delay(Constantes::_MS_ - (tb_while-ta_while));
							
		} // while		

		// Guardamos el tiempo para el bucle.
		tb_for = SDL_GetTicks();

		// Si el tiempo transcurrido es menor al establecido, esperamos.
		if(tb_for - ta_for < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb_for - ta_for));

	} // for
}

void Menu::EliminarDatosElegirPareja()
{
	// Eliminamos los textos y anulamos los punteros.
	for(int x = 0; x < 4; ++x)
	{
		SDL_FreeSurface(stexto_pareja_[x]);
		stexto_pareja_[x] = 0;	
	}
	
	// Eliminamos el texto y anulamos el puntero.
	SDL_FreeSurface(bolas_compartidas_);
	bolas_compartidas_ = 0;

	// Eliminamos el texto y anulamos el puntero.	
	SDL_FreeSurface(bolas_independientes_);
	bolas_independientes_ = 0;
}

int Menu::ElegirPareja()
{

	// Si la música está activada y no está sonando, la reproducimos.
	if(musica_)
		if(!musica_fondo_.Reproduciendo())
			musica_fondo_.Reproducir(1);

	// Lista de opciones.
	enum {PAREJA1, PAREJA2, PAREJA3, NADIE, VOLVER, BOLAS_COMPARTIDAS,
		BOLAS_INDEPENDIENTES};

	// Número de jugadores.	
	int njugadores = datos_jugadores_.size();

	// Nombre del primer jugador.
	std::string nombre = datos_jugadores_[0].nombre_;

	// Creamos la cadena para el texto.
	// Wanna see something amazing?? std::string texto = texto + "amazing.";
	std::string texto;
	texto = texto + "Elige la pareja de " + nombre;

	// Eliminamos la imagen.
	SDL_FreeSurface(stexto_pareja_[0]);

	// Creamos el nuevo texto.
	stexto_pareja_[0] = Utilidades::CrearTexto(texto.c_str(),
		Constantes::_FUENTE_, 28, Utilidades::Color(Utilidades::BLANCO));

	// Guardamos el ancho y el alto de la imagen.
	rtexto_pareja_[0].w = stexto_pareja_[0] -> w;
	rtexto_pareja_[0].h = stexto_pareja_[0] -> h;

	// Establecemos las coordenadas.
	rtexto_pareja_[0].x = pantalla_ -> Ancho() / 2 - rtexto_pareja_[0].w / 2;
	rtexto_pareja_[0].y = pantalla_ -> Alto() / 4 - rtexto_pareja_[0].h / 2 + 12;

	// Eliminamos la imagen.
	SDL_FreeSurface(bolas_compartidas_);

	// Creamos el texto.
	bolas_compartidas_ = Utilidades::CrearTexto("Compartir bola",
		Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

	// Guardamos el ancho y el alto de la imagen.
	rbolas_compartidas_.w = bolas_compartidas_ -> w;
	rbolas_compartidas_.h = bolas_compartidas_ -> h;

	// Establecemos las coordenadas.
	rbolas_compartidas_.x = pantalla_ -> Ancho() / 2
		- rbolas_compartidas_.w / 2;
	rbolas_compartidas_.y = 195;

	// Eliminamos la imagen.
	SDL_FreeSurface(bolas_independientes_);

	// Creamos el texto.
	bolas_independientes_ = Utilidades::CrearTexto("No compartir",
		Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

	// Guardamos el ancho y el alto de la imagen.
	rbolas_independientes_.w = bolas_independientes_ -> w;
	rbolas_independientes_.h = bolas_independientes_ -> h;

	// Establecemos las coordenadas.
	rbolas_independientes_.x = pantalla_ -> Ancho() / 2
		- rbolas_independientes_.w / 2;
	rbolas_independientes_.y = rbolas_compartidas_.y + 64;

	// Hay tres jugadores.
	if(njugadores == 3)
	{
		// Eliminamos la imagen.
		SDL_FreeSurface(stexto_pareja_[1]);

		// Creamos el texto.
		stexto_pareja_[1] =
			Utilidades::CrearTexto(datos_jugadores_[1].nombre_.c_str(),
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

		// Guardamos el ancho y el alto de la imagen.
		rtexto_pareja_[1].w = stexto_pareja_[1] -> w;
		rtexto_pareja_[1].h = stexto_pareja_[1] -> h;

		// Establecemos las coordenadas.
		rtexto_pareja_[1].x = pantalla_ -> Ancho() / 2 - rtexto_pareja_[1].w / 2;
		rtexto_pareja_[1].y = 163;

		// Eliminamos la imagen.
		SDL_FreeSurface(stexto_pareja_[2]);

		// Creamos el texto.
		stexto_pareja_[2] =
			Utilidades::CrearTexto(datos_jugadores_[2].nombre_.c_str(),
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

		// Guardamos el ancho y el alto de la imagen.
		rtexto_pareja_[2].w = stexto_pareja_[2] -> w;
		rtexto_pareja_[2].h = stexto_pareja_[2] -> h;

		// Establecemos las coordenadas.
		rtexto_pareja_[2].x = pantalla_ -> Ancho() / 2 - rtexto_pareja_[2].w / 2;
		rtexto_pareja_[2].y = rtexto_pareja_[1].y + 64;

		// Eliminamos la imagen.
		SDL_FreeSurface(stexto_pareja_[3]);

		// Creamos el texto.
		stexto_pareja_[3] = Utilidades::CrearTexto("Nadie",
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

		// Guardamos el ancho y el alto de la imagen.
		rtexto_pareja_[3].w = stexto_pareja_[3] -> w;
		rtexto_pareja_[3].h = stexto_pareja_[3] -> h;

		// Establecemos las coordenadas.
		rtexto_pareja_[3].x = pantalla_ -> Ancho() / 2 - rtexto_pareja_[3].w / 2;
		rtexto_pareja_[3].y = rtexto_pareja_[1].y + 64 * 2;

	}
	// Hay cuatro jugadores.
	else if(njugadores == 4)
	{
		// Eliminamos la imagen.
		SDL_FreeSurface(stexto_pareja_[1]);

		// Creamos el texto.
		stexto_pareja_[1] =
			Utilidades::CrearTexto(datos_jugadores_[1].nombre_.c_str(),
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

		// Guardamos el ancho y el alto de la imagen.
		rtexto_pareja_[1].w = stexto_pareja_[1] -> w;
		rtexto_pareja_[1].h = stexto_pareja_[1] -> h;

		// Establecemos las coordenadas.
		rtexto_pareja_[1].x = pantalla_ -> Ancho() / 2 - rtexto_pareja_[1].w / 2;
		rtexto_pareja_[1].y = 163;

		// Eliminamos la imagen.
		SDL_FreeSurface(stexto_pareja_[2]);

		// Creamos el texto
		stexto_pareja_[2] =
			Utilidades::CrearTexto(datos_jugadores_[2].nombre_.c_str(),
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

		// Guardamos el ancho y el alto de la imagen.
		rtexto_pareja_[2].w = stexto_pareja_[2] -> w;
		rtexto_pareja_[2].h = stexto_pareja_[2] -> h;

		// Establecemos las coordenadas.
		rtexto_pareja_[2].x = pantalla_ -> Ancho() / 2
			- rtexto_pareja_[2].w / 2;
		rtexto_pareja_[2].y = rtexto_pareja_[1].y + 64;

		// Eliminamos la imagen.
		SDL_FreeSurface(stexto_pareja_[3]);

		// Creamos el texto
		stexto_pareja_[3] =
			Utilidades::CrearTexto(datos_jugadores_[3].nombre_.c_str(),
			Constantes::_FUENTE_, 24, Utilidades::Color(Utilidades::BLANCO));

		// Guardamos el ancho y el alto de la imagen.
		rtexto_pareja_[3].w =	stexto_pareja_[3] -> w;
		rtexto_pareja_[3].h = stexto_pareja_[3] -> h;

		// Establecemos las coordenadas.
		rtexto_pareja_[3].x = pantalla_ -> Ancho() / 2 - rtexto_pareja_[3].w / 2;
		rtexto_pareja_[3].y = rtexto_pareja_[1].y + 64 * 2;
	}

	// Esta variable determina si estamos eligiendo el modo de juego de 
	// Matchplay (bolas compartidas o independientes) o si estamos
	// eligiendo la pareja.
	bool elegir_modo = false;	
	
	// Coordenadas de encuadre para los elementos.
	int xbolas = 271;
	int xparejas = 267; 

	// Establecemos la selección inicial.
	int seleccion = PAREJA1;

	// Establecemos las cordenadas del selector.
	rselector_.x = xparejas;
	rselector_.y = rtexto_pareja_[1].y + rtexto_pareja_[1].h / 2
		- rselector_.h / 2;

	// Dibujamos.
	DibujarElegirPareja();
	pantalla_ -> Actualizar();

	// Variables de control de tiempo para el bucle.
	Uint32 ta_for, tb_for;

	// Varaibles de control de tiempo para el bucle de la cola de eventos.
	Uint32 ta_while, tb_while;

	// Evento a procesar.	
	SDL_Event evento;

	// Tecla del evento.
	SDLKey &tecla = evento.key.keysym.sym;

	for(;;)
	{
		// Guardamos el tiempo para el control del bucle.
		ta_for = SDL_GetTicks();

		// Si la música está activada y no está sonando, la reproducimos.	
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Procesamos la cola de eventos.
		while(SDL_PollEvent(&evento))
		{

			// Guardamos el tiempo para el control del bucle de la cola de eventos.
			ta_while = SDL_GetTicks();
	
			// Si cerramos la ventana terminamos el juego.
			if(evento.type == SDL_QUIT)
				return -1;

			// Se ha pulsado una tecla.
			if(evento.key.type == SDL_KEYDOWN)
			{

				// Pantalla completa.
				if(tecla == teclado_.Tecla(Teclado::PANTALLA_COMPLETA))
					pantalla_ -> PantallaCompleta();

				// Opción de abajo.
				if(tecla == teclado_.Tecla(Teclado::ABAJO))
				{
					switch(seleccion)
					{
						case PAREJA1:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = PAREJA2;

							// Establecemos las coordenadas del selector.
							rselector_.x = xparejas;
							rselector_.y = rtexto_pareja_[2].y
								+ rtexto_pareja_[2].h / 2 - rselector_.h / 2;

							// Dibujamos.
							DibujarElegirPareja();
							pantalla_ -> Actualizar();

							break;
						}
						
						case PAREJA2:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Hay más de tres jugadores.
							if(njugadores > 3)
							{
								// Cambiamos la selección.
								seleccion = PAREJA3;

								// Establecemos las coordenadas del selector.
								rselector_.x = xparejas;
								rselector_.y = rtexto_pareja_[3].y
									+ rtexto_pareja_[3].h / 2 - rselector_.h / 2;
							}
							else
							{
								// Cambiamos la selección.
								seleccion = NADIE;

								// Establecemos las coordenadas del selector.
								rselector_.x = xparejas;
								rselector_.y = rtexto_pareja_[3].y
									+ rtexto_pareja_[3].h / 2 - rselector_.h / 2;
							}

							// Dibujamos.
							DibujarElegirPareja();
							pantalla_ -> Actualizar();

							break;
						}
						case PAREJA3:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = VOLVER;

							// Establecemos las coordenadas del selector.
							rselector_.x = 50;
							rselector_.y = 425;

							// Dibujamos.
							DibujarElegirPareja();
							pantalla_ -> Actualizar();

							break;
						}
						case NADIE:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = VOLVER;

							// Establecemos las coordenadas del selector.
							rselector_.x = 50;
							rselector_.y = 425;

							// Dibujamos.
							DibujarElegirPareja();
							pantalla_ -> Actualizar();						

							break;
						}
						case BOLAS_COMPARTIDAS:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = BOLAS_INDEPENDIENTES;

							// Establecemos las coordenadas del selector.
							rselector_.x = xbolas;
							rselector_.y = rbolas_independientes_.y
								+ rbolas_independientes_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							DibujarElegirModoMatchplay();
							pantalla_ -> Actualizar();						

							break;
						}
						case BOLAS_INDEPENDIENTES:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = VOLVER;

							// Establecemos las coordenadas del selector.
							rselector_.x = 50;
							rselector_.y = 425;

							// Dibujamos.
							DibujarElegirModoMatchplay();
							pantalla_ -> Actualizar();						

							break;
						}					
					}
				}

				// Opción de arriba.
				if(tecla == teclado_.Tecla(Teclado::ARRIBA))
				{
					switch(seleccion)
					{
						case PAREJA2:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = PAREJA1;

							// Establecemos las coordenadas del selector.
							rselector_.x = xparejas;
							rselector_.y = rtexto_pareja_[1].y + rtexto_pareja_[1].h / 2
								- rselector_.h / 2;							

							// Dibujamos.
							DibujarElegirPareja();
							pantalla_ -> Actualizar();
							
							break;
						}
						
						case PAREJA3:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = PAREJA2;

							// Establecemos las coordenadas del selector.
							rselector_.x = xparejas;
							rselector_.y = rtexto_pareja_[2].y + rtexto_pareja_[2].h / 2
								- rselector_.h / 2;

							// Dibujamos.
							DibujarElegirPareja();
							pantalla_ -> Actualizar();

							break;						
						}
						
						case NADIE:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = PAREJA2;

							// Establecemos las coordenadas del selector.
							rselector_.x = xparejas;
							rselector_.y = rtexto_pareja_[2].y +rtexto_pareja_[2].h / 2
								- rselector_.h / 2;

							// Dibujamos.
							DibujarElegirPareja();
							pantalla_ -> Actualizar();

							break;							
						}
						
						case VOLVER:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// No estamos eligiendo modo.
							if(!elegir_modo)
							{
								// El número de jugadores es mayor a tres.
								if(njugadores > 3)
								{
									// Cambiamos la selección.
									seleccion = PAREJA3;

									// Establecemos las coordenadas del selector.
									rselector_.x = xparejas;
									rselector_.y = rtexto_pareja_[3].y
										+ rtexto_pareja_[3].h / 2 - rselector_.h / 2;
								}
								else
								{
									// Cambiamos la selección.
									seleccion = NADIE;

									// Establecemos las coordenadas del selector.
									rselector_.x = xparejas;
									rselector_.y = rtexto_pareja_[3].y
										+ rtexto_pareja_[3].h / 2 - rselector_.h / 2;
								}

								// Dibujamos.
								DibujarElegirPareja();
							}
							else
							{
								// Cambiamos la selección.
								seleccion = BOLAS_INDEPENDIENTES;

								// Establecemos las coordenadas del selector.
								rselector_.x = xbolas;
								rselector_.y = rbolas_independientes_.y
									+ rbolas_independientes_.h / 2 - rselector_.h / 2;

								// Dibujamos.
								DibujarElegirModoMatchplay();						
							}

							// Actualizamos la pantalla.
							pantalla_ -> Actualizar();

							break;						
						}
						case BOLAS_INDEPENDIENTES:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								seleccionar_.Reproducir();

							// Cambiamos la selección.
							seleccion = BOLAS_COMPARTIDAS;

							// Establecemos las coordenadas del selector.
							rselector_.x = xbolas;
							rselector_.y = rbolas_compartidas_.y
								+ rbolas_compartidas_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							DibujarElegirModoMatchplay();
							pantalla_ -> Actualizar();						

							break;
						}						
					}
				}

				// Aceptamos la opción.
				if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
				{
					switch(seleccion)
					{
						case VOLVER:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								cancelar_.Reproducir();

							// No estamos eligiendo modo.
							if(!elegir_modo)
							{
								// Eliminamos los datos y volvemos.
								EliminarDatosElegirPareja();
								return 1;
							}
							else
							{
								// Desactivamos elegir modo.
								elegir_modo = false;

								// Cambiamos la selección.
								seleccion = PAREJA1;

								// Establecemos las coordenadas del selector.
								rselector_.x = xparejas;
								rselector_.y = rtexto_pareja_[1].y
									+ rtexto_pareja_[1].h / 2 - rselector_.h / 2;

								// Dibujamos.
								DibujarElegirPareja();
								pantalla_ -> Actualizar();		
							}
							break;
						}
						case PAREJA1:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Establecemos el primer equipo.
							datos_jugadores_[0].equipo_ = 0;
							datos_jugadores_[1].equipo_ = 0;

							// Si hay cuatro jugadores, establecemos el segundo equipo.
							if(njugadores_ > 3)
							{
								datos_jugadores_[2].equipo_ = 1;
								datos_jugadores_[3].equipo_ = 1;
							}
							// Hay tres jugadores. Establecemos el segundo equipo.
							else
								datos_jugadores_[2].equipo_ = 1;
							
							// Tenemos que elegir el modo.
							elegir_modo = true;

							// Cambiamos la selección.
							seleccion = BOLAS_COMPARTIDAS;

							// Establecemos las coordenadas del selector.
							rselector_.x = xbolas;
							rselector_.y = rbolas_compartidas_.y
								+ rbolas_compartidas_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							DibujarElegirModoMatchplay();
							pantalla_ -> Actualizar();

							break;
						}
						case PAREJA2:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Establecemos el primer equipo.
							datos_jugadores_[0].equipo_ = 0;
							datos_jugadores_[2].equipo_ = 0;

							// Si hay cuatro jugadores, establecemos el segundo equipo.
							if(njugadores_ > 3)
							{
								datos_jugadores_[1].equipo_ = 1;
								datos_jugadores_[3].equipo_ = 1;
							
							}
							// Hay tres jugadores. Establecemos el segundo equipo.
							else
								datos_jugadores_[1].equipo_ = 1;							

							// Tenemos que elegir el modo.
							elegir_modo = true;

							// Cambiamos la selección.
							seleccion = BOLAS_COMPARTIDAS;

							// Establecemos las coordenadas del selector.
							rselector_.x = xbolas;
							rselector_.y = rbolas_compartidas_.y
								+ rbolas_compartidas_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							DibujarElegirModoMatchplay();
							pantalla_ -> Actualizar();

							break;
						}
						case PAREJA3:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Establecemos los equipos.
							datos_jugadores_[0].equipo_ = 0;
							datos_jugadores_[3].equipo_ = 0;
							datos_jugadores_[1].equipo_ = 1;
							datos_jugadores_[2].equipo_ = 1;

							// Tenemos que elegir el modo.
							elegir_modo = true;

							// Cambiamos la selección.
							seleccion = BOLAS_COMPARTIDAS;

							// Establecemos las coordenadas del selector.
							rselector_.x = xbolas;
							rselector_.y = rbolas_compartidas_.y
								+ rbolas_compartidas_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							DibujarElegirModoMatchplay();
							pantalla_ -> Actualizar();
				
							break;
						}
						case NADIE:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Establecemos los equipos.
							datos_jugadores_[0].equipo_ = 0;
							datos_jugadores_[1].equipo_ = 1;
							datos_jugadores_[2].equipo_ = 1;
							
							// Tenemos que elegir el modo.
							elegir_modo = true;

							// Cambiamos la selección.
							seleccion = BOLAS_COMPARTIDAS;

							// Establecemos las coordenadas del selector.
							rselector_.x = xbolas;
							rselector_.y = rbolas_compartidas_.y
								+ rbolas_compartidas_.h / 2 - rselector_.h / 2;

							// Dibujamos.
							DibujarElegirModoMatchplay();
							pantalla_ -> Actualizar();
					
							break;
						}
						case BOLAS_COMPARTIDAS:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Establecemos el tipo de matchplay.
							tipo_matchplay_ = Matchplay::BOLAS_COMPARTIDAS;

							// Guardamos el retorno del menú de elegir campo.
							int retorno = ElegirCampo(MATCHPLAY);
							
							// Hemos vuelto de ElegirCampo a ElegirJugadores.
							if(retorno == 1)
							{
								// Tenemos que elegir el modo.
								elegir_modo = true;

								// Cambiamos la selección.
								seleccion = BOLAS_COMPARTIDAS;

								// Establecemos las coordenadas del selector.
								rselector_.x = xbolas;
								rselector_.y = rbolas_compartidas_.y
									+ rbolas_compartidas_.h / 2 - rselector_.h / 2;

								// Dibujamos.
								DibujarElegirModoMatchplay();
								pantalla_ -> Actualizar();
							}
							// Hemos vuelto desde el menú de pausa, la opción salir.
							else if(retorno == 0)
								return 0;
							// Hemos cerrado la ventana. Terminamos el juego.
							else if(retorno == -1)
								return -1;

							break;
						}
						case BOLAS_INDEPENDIENTES:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Establecemos el tipo de matchplay.
							tipo_matchplay_ = Matchplay::BOLAS_INDEPENDIENTES;

							// Guardamos el retorno del menú de elegir campo.
							int retorno = ElegirCampo(MATCHPLAY);

							// Hemos vuelto de ElegirCampo a ElegirJugadores.
							if(retorno == 1)
							{
								// Tenemos que elegir el modo.
								elegir_modo = true;

								// Cambiamos la selección.
								seleccion = BOLAS_COMPARTIDAS;

								// Establecemos las coordenadas del selector.
								rselector_.x = xbolas;
								rselector_.y = rbolas_compartidas_.y
									+ rbolas_compartidas_.h / 2 - rselector_.h / 2;

								// Dibujamos.
								DibujarElegirModoMatchplay();
								pantalla_ -> Actualizar();
							}
							// Hemos vuelto desde el menú de pausa, la opción salir.
							else if(retorno == 0)
								return 0;
							// Hemos pulsado la x de cerrar ventana.
							else if(retorno == -1)
								return -1;

							break;
						}						
						
					}
				}
			}
			// Guardamos el tiempo para la cola de eventos.
			tb_while = SDL_GetTicks();

			// Si el tiempo transcurrido es menor al establecido, esperamos.
			if(tb_while - ta_while < Constantes::_MS_)
				SDL_Delay(Constantes::_MS_ - (tb_while-ta_while));
							
		} // while		

		// Guardamos el tiempo para el bucle.
		tb_for = SDL_GetTicks();

		// Si el tiempo transcurrido es menor al establecido, esperamos.
		if(tb_for - ta_for < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb_for - ta_for));

	} // for
}

int Menu::Pausa()
{
	// Si los efectos están activados, lo reproducimos.
	if(efectos_)
		cancelar_.Reproducir();

	// Si la música está activada y no está sonando, la reproducimos.		
	if(musica_)
		if(musica_fondo_.Reproduciendo())
			Mix_PauseMusic();

	// Opciones disponibles.
	enum {CONTINUAR, SALIR, SI, NO};

	// Varaibles de referencia para el encuadre de las imágenes.	
	int xcontinuar = 323;
	int ycontinuar = 227;
	int xsalir = 350;
	int ysalir = 266;
	int xsi = 355;
	int ysi = 266;
	int xno = 355;
	int yno = 227;

	// Imagen de fondo sobre la que pintaremos el menú de pausa.
	SDL_Surface* fondo = 0;
	SDL_Rect rfondo;
	rfondo.x = 0;
	rfondo.y = 0;

	// Copiamos la pantalla a la imagen de fondo.
	pantalla_ -> Copiar(&fondo);
	
	// Establecemos las coordenadas del selector.
	rselector_.x = xcontinuar;
	rselector_.y = ycontinuar;

	// Establecemos la selección inicial.
	int seleccion = CONTINUAR;


	// Dibujamos.
	pantalla_ -> DibujarDirectamente(pausa_, &rfondo_);
	pantalla_ -> DibujarDirectamente(mpausa_, &rmpausa_);
	pantalla_ -> DibujarDirectamente(selector_, &rselector_);
	pantalla_ -> Actualizar();

	// Evento a procesar.
	SDL_Event evento;

	// Tecla del evento.
	SDLKey &tecla = evento.key.keysym.sym;

	// Variables de control de tiempo para el bucle.
	Uint32 ta_for, tb_for;

	// Varaibles de control de tiempo para el bucle de la cola de eventos.
	Uint32 ta_while, tb_while;	

	for(;;)
	{
		// Guardamos el tiempo para el control del bucle.
		ta_for = SDL_GetTicks();

		// Si la música está activada y no está sonando, la reproducimos.	
		if(musica_)
			if(!musica_fondo_.Reproduciendo())
				musica_fondo_.Reproducir(1);

		// Procesamos la cola de eventos.
		while(SDL_PollEvent(&evento))
		{
			// Guardamos el tiempo para el control del bucle de la cola de eventos.
			ta_while = SDL_GetTicks();

			// Si cerramos la ventana terminamos el juego.
			if(evento.type == SDL_QUIT)
			{
				// Eliminamos la copia del fondo
				SDL_FreeSurface(fondo);
				return 1;
			}

			// Se ha pulsado una tecla.
			if(evento.type == SDL_KEYDOWN)
			{
				// Pantalla completa.
				if(tecla == teclado_.Tecla(Teclado::PANTALLA_COMPLETA))
					pantalla_ -> PantallaCompleta();

				// Aceptamos.
				if(tecla == teclado_.Tecla(Teclado::ACEPTAR))
				{
					switch(seleccion)
					{
						case CONTINUAR:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Si la música está activada, la activamos de nuevo.
							if(musica_)
								if(musica_fondo_.Reproduciendo())
									Mix_ResumeMusic();
							
							// Destruimos la copia del fondo.
							SDL_FreeSurface(fondo);

							return 0;
						}
					
						case SALIR:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Cambiamos la selección.
							seleccion = NO;

							// Establecemos las coordenadas del selector.
							rselector_.x = xno;
							rselector_.y = yno;

							// Dibujamos.
							pantalla_ -> DibujarDirectamente(fondo, &rfondo);
							pantalla_ -> DibujarDirectamente(pausa_, &rfondo_);
							pantalla_ -> DibujarDirectamente(mseguro_, &rmseguro_);
							pantalla_ -> DibujarDirectamente(selector_, &rselector_);
							pantalla_ -> Actualizar();

							break;		
						}
					
						case SI:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								cancelar_.Reproducir();

							// Si la música está activada, la activamos de nuevo.
							if(musica_)
								if(musica_fondo_.Reproduciendo())
									Mix_ResumeMusic();

							// Destruimos la copia del fondo.
							SDL_FreeSurface(fondo);

							return -1;
						}
						
						case NO:
						{
							// Si los efectos están activados, lo reproducimos.
							if(efectos_)
								aceptar_.Reproducir();

							// Cambiamos la selección.
							seleccion = CONTINUAR;

							// Establecemos las coordenadas del selector.
							rselector_.x = xcontinuar;
							rselector_.y = ycontinuar;

							// Dibujamos.
							pantalla_ -> DibujarDirectamente(fondo, &rfondo);
							pantalla_ -> DibujarDirectamente(pausa_, &rfondo_);
							pantalla_ -> DibujarDirectamente(mpausa_, &rmpausa_);
							pantalla_ -> DibujarDirectamente(selector_, &rselector_);
							pantalla_ -> Actualizar();						
						}
						
					}
				}

				// Opción de abajo.
				if(tecla == teclado_.Tecla(Teclado::ABAJO))
				{
					if(seleccion == CONTINUAR)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Cambiamos la selección.
						seleccion = SALIR;

						// Establecemos las coordenadas del selector.
						rselector_.x = xsalir;
						rselector_.y = ysalir;

						// Dibujamos.
						pantalla_ -> DibujarDirectamente(fondo, &rfondo);
						pantalla_ -> DibujarDirectamente(pausa_, &rfondo_);
						pantalla_ -> DibujarDirectamente(mpausa_, &rmpausa_);
						pantalla_ -> DibujarDirectamente(selector_, &rselector_);
						pantalla_ -> Actualizar();
					}
					else if(seleccion == NO)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Cambiamos la selección.
						seleccion = SI;

						// Establecemos las coordenadas del selector.
						rselector_.x = xsi;
						rselector_.y = ysi;

						// Dibujamos.
						pantalla_ -> DibujarDirectamente(fondo, &rfondo);
						pantalla_ -> DibujarDirectamente(pausa_, &rfondo_);
						pantalla_ -> DibujarDirectamente(mseguro_, &rmseguro_);
						pantalla_ -> DibujarDirectamente(selector_, &rselector_);
						pantalla_ -> Actualizar();					
					}		
				}

				// Opción de abajo.
				if(tecla == teclado_.Tecla(Teclado::ARRIBA))
				{
					if(seleccion == SALIR)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Cambiamos la selección.
						seleccion = CONTINUAR;

						// Establecemos las coordenadas del selector.
						rselector_.x = xcontinuar;
						rselector_.y = ycontinuar;

						// Dibujamos.	
						pantalla_ -> DibujarDirectamente(fondo, &rfondo);
						pantalla_ -> DibujarDirectamente(pausa_, &rfondo_);
						pantalla_ -> DibujarDirectamente(mpausa_, &rmpausa_);
						pantalla_ -> DibujarDirectamente(selector_, &rselector_);
						pantalla_ -> Actualizar();
					}
					else if(seleccion == SI)
					{
						// Si los efectos están activados, lo reproducimos.
						if(efectos_)
							seleccionar_.Reproducir();

						// Cambiamos la selección.
						seleccion = NO;

						// Establecemos las coordenadas del selector.
						rselector_.x = xno;
						rselector_.y = yno;

						// Dibujamos.
						pantalla_ -> DibujarDirectamente(fondo, &rfondo);
						pantalla_ -> DibujarDirectamente(pausa_, &rfondo_);
						pantalla_ -> DibujarDirectamente(mseguro_, &rmseguro_);
						pantalla_ -> DibujarDirectamente(selector_, &rselector_);
						pantalla_ -> Actualizar();					
					}	
				}
			}

	
			// Guardamos el tiempo para la cola de eventos.
			tb_while = SDL_GetTicks();

			// Si el tiempo transcurrido es menor al establecido, esperamos.
			if(tb_while - ta_while < Constantes::_MS_)
				SDL_Delay(Constantes::_MS_ - (tb_while - ta_while));

		}

		// Guardamos el tiempo para el bucle.
		tb_for = SDL_GetTicks();

		// Si el tiempo transcurrido es menor al establecido, esperamos.
		if(tb_for - ta_for < Constantes::_MS_)
			SDL_Delay(Constantes::_MS_ - (tb_for - ta_for));

	}
}

bool Menu::EfectosActivos() const
{
	// Devolvemos el estado de los efectos de sonido.
	return efectos_;
}

bool Menu::MusicaActiva() const
{
	// Devolvemos el estado de la música del juego.
	return musica_;
}

std::string Menu::RutaImagen(const char *imagen)
{
	// Generamos la ruta a la imagen.
	std::string ruta = Constantes::_IMG_MENU_;
	std::string img = imagen;

	// La devolvemos.
	return ruta += img;
}

std::string Menu::RutaSonido(const char *sonido)
{
	// Generamos la ruta al sonido.
	std::string ruta = Constantes::_SND_EFECTOS_;
	std::string snd = sonido;
	
	// La devolvemos.
	return ruta += snd;
}
