/// \file musica.cpp Música del juego.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <iostream>
#include "musica.h"

Musica::Musica()
{
	// Todavía no hemos cargado la música. Ponemos el puntero a nulo.
	musica_ = 0;
}

Musica::~Musica()
{
	// Destruimos la música.
	Mix_FreeMusic(musica_);
}

void Musica::Cargar(std::string ruta)
{
	// Establecemos el volumen de la música.
	Mix_VolumeMusic(80);

	// Generamos la ruta de la cadena.
	const char *cadena = ruta.c_str();

	// Cargamos la música.
	musica_ = Mix_LoadMUS(cadena);

	// Comprobamos si la música se ha cargado correctamente.
	if(!musica_) 
	{
		std::cerr << "musica.cpp: Cargar() Error: " << Mix_GetError() << std::endl;
		exit(1);
	}
}

void Musica::Reproducir(int veces) const
{
	// Reproducimos la música y comprobamos que no se produzca error.
	if(Mix_PlayMusic(musica_, veces) == -1)
	{
		std::cerr << "musica.cpp: Reproducir() Error: " << Mix_GetError()
			<< std::endl;
		exit(1);
	}
}

bool Musica::Reproduciendo() const
{
	// La música está reproduciéndose.
	if(Mix_PlayingMusic() == 0)
		return false;

	// La música no está reproduciéndose.
	else
		return true;
}

