/// \file musica.h Música del juego.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _MUSICA_H_
#define _MUSICA_H_

#include <SDL/SDL_mixer.h>

/*! \class Musica
    \brief Música del juego.

    La clase música permite dotar de música de fondo al menú del juego y
    generar sonido ambiental en la partida que esté en curso.
 */
class Musica
{
	public:

		/*! Establece el puntero a la canción como nulo.
				\brief Constructor.
		 */
		Musica();

		/*! Destruye la música que se ha cargado.
				\brief Destructor.
		 */		
		~Musica();

		/*! \brief Carga el fichero de música.
				\param ruta Ruta al fichero de música.
		 */		
		void Cargar(std::string ruta);

		/*! \brief Reproduce el fichero de música.
				\param veces \arg \b -1 Reproduce la música constantemente.
										 \arg \b n Reproduce la música \e n veces.
				\see Menu::MusicaActiva.
		 */		
		void Reproducir(int veces) const;

		/*! \brief Función observadora.
				\return \arg \b Verdadero Si la música se está reproduciendo.
								\arg \b Falso Si la música no se está reproduciendo.
		 */		
		bool Reproduciendo() const;
	
	private:
	
		Mix_Music *musica_;	///< Música cargada.
};

#endif
