/// \file palo.h Palo de golf.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _PALO_H_
#define _PALO_H_

#include <iostream>

/*! \class Palo
    \brief Palo de golf.

    El palo de golf es uno de los elementos básicos del juego. Con él se
    podrá llevar a cabo el lanzamiento de la bola de golf.
    
    Cada palo de golf viene determinado por unas características propias.
    Todos poseen un nombre, un alcance máximo y un ángulo de tiro. Cuanto
    mayor sea dicho el ángulo de tiro, más altura podrá alcanzar la bola
    pero menos alcance tendrá el lanzamiento.
 */
class Palo
{
	public:

		/*! Establece el nombre, el alcance y el ángulo de salida del palo.
				\brief Constructor.
				\param nombre Nombre del palo de golf.
				\param alcance_maximo Alcance máximo (en metros) del palo de golf.
				\param angulo_salida Ángulo de salida de la Bola al ser golpeada por
														 el palo.
				\see Jugador.
		 */
		Palo(std::string nombre, int alcance_maximo, int angulo_salida);

		/*! \brief Ángulo de salida de la Bola al ser golpeada por el palo.
				\return Ángulo de salida.
		 */
		int AnguloSalida() const;

		/*! \brief Alcance máximo del palo de golf convertido a la proporción
							 del juego.
				\return Alcance máximo del palo.
		 */
		int AlcanceMaximo() const;

		/*! \brief Alcance máximo (en metros) del palo de golf.
				\return Alcance real del palo.
		 */
		int AlcanceReal() const;

		/*! \brief Nombre del palo de golf.
				\return Nombre del palo.
		 */
		std::string Nombre() const;

	private:
	
		std::string nombre_;	///< Nombre del palo.
		
		int alcance_maximo_;	///< Alcane máximo real.
		
		int angulo_salida_;	///< Ángulo de salida que aplica a la Bola.
};

#endif
