/// \file practicar.h Partida de práctica.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _PRACTICAR_H_
#define _PRACTICAR_H_

#include "partida.h"
#include "datos.h"


/*! \class Practicar.
    \brief Modo de juego de práctica.

    Implementación del modo de juego Practicar.
    
    En una partida de práctica, uno o varios jugadores pueden practicar un
    determinado hoyo de un campo.
    
    No existen ganadores en este modo de juego.
 */
class Practicar: public Partida
{
	public:
	
		/*! Realiza las asociaciones con el Menu y la Pantalla.\n
				Crea y asigna las bolas de golf y los jugadores.\n
				Inicializa las puntuaciones a 0 y carga el Campo.\n
				Coloca las Bolas sobre el Campo, actualiza la lista de bolas inactivas
				y activa el primer Jugador.\n
				Crea las animaciones de las colisiones de la Bola con los elementos
				del Campo.
				
				\brief Constructor.
				\param jugadores Datos de los jugadores que participan en la Partida.
				\param campo Datos del campo en el que se desarrollará la Partida.
				\param menu Menú del Juego.
				\param pantalla Pantalla del Juego.
				\see Campo::LugarSalida.
				\see Campo::ElementosCampo.
				\see Datos::Jugador.
				\see Datos::Campo.
		 */
		Practicar(std::vector<Datos::Jugador>& jugadores,
			Datos::Campo& campo, Menu* menu, Pantalla *pantalla);
		
		/*! \brief Inicia la partida.
				\return \arg \b 0 hemos salido de la Partida desde el Menu de pausa.
								\arg \b -1 hemos cerrado la ventana del Juego.
				\see Menu::Pausa.
		 */		
		int Iniciar();
};

#endif
