/// \file rejilla.cpp Rejilla de imágenes.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <iostream>
#include "rejilla.h"
#include "utilidades.h"

Rejilla::Rejilla(std::string ruta, int filas, int columnas)
{
	// Cargamos la imagen de la rejilla.
	rejilla_ = Utilidades::CargarImagen(ruta);

	// Establecemos el número de filas de la rejilla.
	filas_ = filas;
	
	// Establecemos el número de columnas de la rejilla.
	columnas_ = columnas;

	// Establecemos el ancho del cuadro de la rejilla.
	if(columnas > 1)
		rrejilla_.w = rejilla_ -> w / columnas_ - 1;
	else
		rrejilla_.w = rejilla_ -> w / columnas_ - 2;

	// Establecemos el alto del cuadro de la rejilla.
	if(filas > 1)
		rrejilla_.h = rejilla_ -> h / filas_ - 1;
	else
		rrejilla_.h = rejilla_ -> h / filas_ - 2;	

	// Seleccionamos un cuadro inválido.
	cuadro_ = -1;
}

Rejilla::~Rejilla()
{
	// Destruimos la imagen de la rejilla.
	SDL_FreeSurface(rejilla_);
}

void Rejilla::SeleccionarCuadro(int posicion)
{
	// Seleccionamos la columna.
	rrejilla_.x = ((posicion % columnas_) * rejilla_ -> w / columnas_) + 1;
	
	// Seleccionamos la fila.
	rrejilla_.y = ((posicion / columnas_) * rejilla_ -> h / filas_) + 1;
	
	// Actualizamos el cuadro seleccionado.
	cuadro_ = posicion;
}

int Rejilla::TotalCuadros() const
{
	// Devolvemos el total de cuadros que tiene la rejilla.
	return filas_ * columnas_;
}

SDL_Rect& Rejilla::Posicion()
{
	// Devolvemos la posición de la rejilla.
	return rrejilla_;
}

SDL_Surface * Rejilla::Imagen()
{
	// Devolvemos la imagen de la rejilla.
	return rejilla_;
}

int Rejilla::CuadroActual() const
{
	// Devolvemos el cuadro seleccionado.
	return cuadro_;
}

