/// \file sonido.cpp Efecto de sonido.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <iostream>
#include "sonido.h"

Sonido::Sonido()
{
	// Establecemos el puntero a nulo.
	sonido_ = 0;
}

Sonido::~Sonido()
{
	// Destruimos el sonido.
	Mix_FreeChunk(sonido_);
}

void Sonido::Cargar(std::string ruta)
{
	// Convertimos la cadena.
	const char *cadena;
	cadena = ruta.c_str();
	
	// Cargamos el sonido.
	sonido_ = Mix_LoadWAV(cadena);

	// Comprobamos que se ha cargado correctamente.
	if(!sonido_)
	{
		std::cerr << "sonido.cpp: Cargar() Error: " << Mix_GetError() << std::endl;
		exit(1);
	}	
}

void Sonido::Reproducir()
{
	// Reproducimos el sonido y comprobamos que se haya reproducido
	// correctamente.
	if(Mix_PlayChannel(-1, sonido_, 0) == -1)
	{
		  std::cerr << "sonido.cpp: Reproducir() Error: "
		  	<< Mix_GetError() << std::endl;
			exit(1);
	}

}
