/// \file sonido.h Efecto de sonido.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _SONIDO_H_
#define _SONIDO_H_

#include <SDL/SDL_mixer.h>

/*! \class Sonido.
    \brief Efectos de sonido.

    Esta clase se encarga de generar los efectos de sonido que se producen
    en el juego, tales como la colisión de la bola con los elementos del
    campo, los efectos de sonido del menú, el efecto de sonido que produce
    el palo al impactar contra la bola, etc.
 */
class Sonido
{
	public:
	
		/*! Establece el puntero al sonido como nulo.
				\brief Constructor.
		 */
		Sonido();
		
		/*! Destruye el efecto de sonido.
				\brief Destructor.
		 */
		~Sonido();
		
		/*! \brief Carga el fichero de sonido.
				\param ruta Ruta al fichero de sonido.
		 */		
		void Cargar(std::string ruta);
		
		/*!	\brief Reproduce el efecto de sonido.
				\see Menu::EfectosActivos.
		 */
		void Reproducir();
	
	private:
	
		Mix_Chunk *sonido_;	///< Efecto de sonido.
		
};

#endif
