/// \file teclado.cpp Teclado.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <SDL/SDL.h>
#include <iostream>
#include <ctype.h>
#include "teclado.h"
#include "constantes.h"


Teclado::Teclado()
{
	// Asignación de teclas.
	teclas_[PANTALLA_COMPLETA] = SDLK_F11;
	teclas_[ARRIBA] = SDLK_UP;
	teclas_[ABAJO] = SDLK_DOWN;
	teclas_[IZQUIERDA] = SDLK_LEFT;
	teclas_[DERECHA] = SDLK_RIGHT;
	teclas_[ESPACIO] = SDLK_SPACE;
	teclas_[ESCAPE] = SDLK_ESCAPE;
	teclas_[ACEPTAR] = SDLK_RETURN;
	teclas_[INTRO] = SDLK_KP_ENTER;
	teclas_[MAPA] = SDLK_m;
	teclas_[BORRAR] = SDLK_BACKSPACE;
	teclas_[PAUSA] = SDLK_p;
}

SDLKey& Teclado::Tecla(int tecla)
{
	// Devolvemos la tecla asignada.
	return teclas_[tecla];
}

char Teclado::ObtenerUnicode(const SDL_KeyboardEvent *evento)
{
	// Tecla del evento.
	SDLKey tecla = evento -> keysym.sym;
	
	// Teclas no válidas.
	if(tecla == SDLK_DELETE || tecla == SDLK_ESCAPE
		|| tecla == SDLK_BACKSPACE || tecla == SDLK_TAB || tecla == SDLK_CLEAR
		|| tecla == SDLK_RETURN || tecla == SDLK_PAUSE || tecla == SDLK_KP_ENTER)
		return 0;
	
	// Teclas modificadoras no válidas.
	if(SDL_GetModState() & KMOD_ALT || SDL_GetModState() & KMOD_CTRL
		|| SDL_GetModState() & KMOD_META || SDL_GetModState() & KMOD_MODE)
		return 0;

	int unicode = evento -> keysym.unicode;

	// La tecla no se puede convertir a Unicode (por ejemplo el cursor).
	if(unicode == 0)
		return 0;

	if((unicode & Constantes::_INTERNATIONAL_MASK_) == 0)
	{
		// Mayus está activado.
		if(SDL_GetModState() & KMOD_SHIFT)
			return (char)(toupper(unicode & Constantes::_UNICODE_MASK_));
		else
			return (char)(unicode & Constantes::_UNICODE_MASK_);
	}
	// Caracter internacional que no se puede leer.
  else
		return '?';
}
