/// \file teclado.h Teclado.
/*
	Copyright 2010 Andrés Francisco Aparicio

	This file is part of SDLgolf.

	SDLgolf is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	SDLgolf is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SDLgolf.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _TECLADO_H_
#define _TECLADO_H_

#include <SDL/SDL.h>

/*! \class Teclado.
    \brief Teclado del juego.

    En esta clase se definen las teclas del juego y los métodos de
    control del teclado.
 */
class Teclado
{
	public:

		/*! Realiza la asignación de teclas.
				\brief Constructor.
				\see Teclas.
		 */
		Teclado();

		/*! \enum Teclas
		  	\brief Teclas configuradas.

				\var PANTALLA_COMPLETA
		 		Tecla para establecer el modo de pantalla completa.
		 		
		 		\var ABAJO
		 		Cursor abajo.
		 		
		 		\var ARRIBA
		 		Cursor arriba.
		 		
		 		\var IZQUIERDA
		 		Cursor izquierda.
		 		
		 		\var DERECHA
		 		Cursor derecha.
		 		
		 		\var ESPACIO
		 		Tecla espacio.
		 		
		 		\var ESCAPE
		 		Tecla escape.
		 		
		 		\var ACEPTAR
		 		Tecla enter.
		 		
		 		\var INTRO
		 		Tecla intro.
		 		
		 		\var MAPA
		 		Tecla para la activación/desactivación del mapa.
		 		
		 		\var PAUSA
		 		Tecla para pausar el juego.
		 		
		 		\var BORRAR
		 		Tecla backspace.
		 		
		 		\var N_TECLAS
		 		Número total de teclas configuradas.

		 */	
		enum Teclas 
		{
			PANTALLA_COMPLETA,
			ABAJO,
			ARRIBA,
			IZQUIERDA,
			DERECHA,
			ESPACIO,
			ESCAPE,
			ACEPTAR,
			INTRO,
			MAPA,
			PAUSA,
			BORRAR,
			N_TECLAS
		};	

		/*!	\brief Devuelve la tecla asignada.
				\param tecla Tecla que queremos obtener.
				\return Tecla asignada.
				\see Teclas.
		 */
		SDLKey& Tecla(int tecla);
		
		/*! \brief Caracter unicode de una tecla.
				\param evento Evento del teclado a procesar.
				\return Carácter unicode de la tecla pulsada.
		 */
		char ObtenerUnicode(const SDL_KeyboardEvent *evento);
		
	private:

		SDLKey teclas_[N_TECLAS];	///< Teclas configuradas.

};

#endif
